"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "createMarkdownActions", {
    enumerable: true,
    get: function() {
        return createMarkdownActions;
    }
});
const _ConfirmInsertAssetModalDialog = require("./dialogs/ConfirmInsertAssetModalDialog");
const _EmdebExternalContentDialog = require("./dialogs/EmdebExternalContentDialog");
const _InsertLinkModalDialog = require("./dialogs/InsertLinkModalDialog");
const _InsertTableModalDialog = require("./dialogs/InsertTableModalDialog");
const _SpecialCharacterModalDialog = require("./dialogs/SpecialCharacterModalDialog");
const _ZenModeModalDialog = require("./dialogs/ZenModeModalDialog");
const _insertAssetLinks = require("./utils/insertAssetLinks");
const _linkOrganizer = /*#__PURE__*/ _interop_require_wildcard(require("./utils/linkOrganizer"));
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
function createMarkdownActions(props) {
    const { sdk, editor, locale } = props;
    const insertAssetsWithConfirmation = async (assets)=>{
        if (assets) {
            const { links, fallbacks } = await (0, _insertAssetLinks.insertAssetLinks)(assets, {
                localeCode: locale,
                defaultLocaleCode: sdk.locales.default,
                fallbackCode: sdk.locales.fallbacks[locale]
            });
            if (links && links.length > 0) {
                if (fallbacks) {
                    const insertAnyway = await (0, _ConfirmInsertAssetModalDialog.openConfirmInsertAsset)(sdk.dialogs, {
                        locale: locale,
                        assets: fallbacks
                    });
                    if (!insertAnyway) {
                        throw Error('User decided to not use fallbacks');
                    }
                }
                return links.map((link)=>link.asMarkdown).join('\n\n');
            }
        }
        return '';
    };
    return {
        headings: {
            h1: ()=>{
                editor?.actions.h1();
            },
            h2: ()=>{
                editor?.actions.h2();
            },
            h3: ()=>{
                editor?.actions.h3();
            }
        },
        simple: {
            italic: ()=>{
                editor?.actions.italic();
            },
            bold: ()=>{
                editor?.actions.bold();
            },
            quote: ()=>{
                editor?.actions.quote();
            },
            ol: ()=>{
                editor?.actions.ol();
            },
            ul: ()=>{
                editor?.actions.ul();
            },
            strike: ()=>{
                editor?.actions.strike();
            },
            code: ()=>{
                editor?.actions.code();
            },
            hr: ()=>{
                editor?.actions.hr();
            },
            indent: ()=>{
                editor?.actions.indent();
            },
            dedent: ()=>{
                editor?.actions.dedent();
            }
        },
        history: {
            undo: ()=>{
                editor?.actions.undo();
            },
            redo: ()=>{
                editor?.actions.redo();
            }
        },
        insertLink: async ()=>{
            if (!editor) {
                return;
            }
            editor.usePrimarySelection();
            const selectedText = editor.getSelectedText();
            const result = await (0, _InsertLinkModalDialog.openInsertLinkDialog)(sdk.dialogs, {
                selectedText
            });
            if (result) {
                editor.actions.link(result.url, selectedText || result.text, result.title);
            }
        },
        insertSpecialCharacter: async ()=>{
            if (!editor) {
                return;
            }
            const result = await (0, _SpecialCharacterModalDialog.openInsertSpecialCharacter)(sdk.dialogs);
            if (result) {
                editor.insert(result);
            }
        },
        insertTable: async ()=>{
            if (!editor) {
                return;
            }
            const result = await (0, _InsertTableModalDialog.openInsertTableDialog)(sdk.dialogs);
            if (result) {
                editor.actions.table(result);
            }
        },
        organizeLinks: ()=>{
            if (!editor) {
                return;
            }
            let text = editor.getContent();
            if (!text) {
                return;
            }
            text = _linkOrganizer.convertInlineToRef(text);
            text = _linkOrganizer.rewriteRefs(text);
            editor.setContent(text);
            sdk.notifier.success('All your links are now references at the bottom of your document.');
        },
        embedExternalContent: async ()=>{
            if (!editor) {
                return;
            }
            const result = await (0, _EmdebExternalContentDialog.openEmbedExternalContentDialog)(sdk.dialogs);
            if (result) {
                editor.insert(result);
            }
        },
        addNewMedia: async ()=>{
            if (!editor) {
                return;
            }
            try {
                const { entity: asset } = await sdk.navigator.openNewAsset({
                    slideIn: {
                        waitForClose: true
                    }
                });
                const markdownLinks = await insertAssetsWithConfirmation([
                    asset
                ]);
                editor.insert(markdownLinks);
            } finally{
                editor.focus();
            }
        },
        linkExistingMedia: async ()=>{
            if (!editor) {
                return;
            }
            try {
                const assets = await sdk.dialogs.selectMultipleAssets({
                    locale: locale
                });
                const markdownLinks = await insertAssetsWithConfirmation(assets);
                editor.insert(markdownLinks);
            } finally{
                editor.focus();
            }
        },
        openZenMode: async ()=>{
            if (!editor) {
                return;
            }
            const result = await (0, _ZenModeModalDialog.openZenMode)(sdk.dialogs, {
                initialValue: editor.getContent(),
                locale: props.locale
            });
            editor.setContent(result.value);
            if (result.cursor) {
                editor.setCursor(result.cursor);
            }
            editor.focus();
        },
        closeZenMode: ()=>{}
    };
}
