"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    MarkdownEditor: function() {
        return MarkdownEditor;
    },
    MarkdownEditorConnected: function() {
        return MarkdownEditorConnected;
    }
});
const _react = /*#__PURE__*/ _interop_require_wildcard(require("react"));
const _f36tokens = /*#__PURE__*/ _interop_require_default(require("@contentful/f36-tokens"));
const _fieldeditorshared = require("@contentful/field-editor-shared");
const _emotion = require("emotion");
const _MarkdownBottomBar = require("./components/MarkdownBottomBar");
const _MarkdownConstraints = require("./components/MarkdownConstraints");
const _MarkdownPreviewSkeleton = /*#__PURE__*/ _interop_require_default(require("./components/MarkdownPreviewSkeleton"));
const _MarkdownTabs = require("./components/MarkdownTabs");
const _MarkdownTextarea = require("./components/MarkdownTextarea/MarkdownTextarea");
const _MarkdownToolbar = require("./components/MarkdownToolbar");
const _CheatsheetModalDialog = require("./dialogs/CheatsheetModalDialog");
const _MarkdownActions = require("./MarkdownActions");
function _interop_require_default(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
const MarkdownPreview = /*#__PURE__*/ _react.lazy(()=>Promise.resolve().then(()=>/*#__PURE__*/ _interop_require_wildcard(require("./components/MarkdownPreview"))));
const styles = {
    container: (0, _emotion.css)({
        display: 'flex',
        flexDirection: 'column',
        fontFamily: _f36tokens.default.fontStackPrimary
    })
};
function MarkdownEditor(props) {
    const prevExternalReset = _react.useRef(props.externalReset);
    const [currentValue, setCurrentValue] = _react.useState(props.value ?? '');
    const [selectedTab, setSelectedTab] = _react.useState('editor');
    const [editor, setEditor] = _react.useState(null);
    const [canUploadAssets, setCanUploadAssets] = _react.useState(false);
    _react.useEffect(()=>{
        if (props.enableTab) {
            setSelectedTab(props.enableTab);
        }
    }, [
        props.enableTab
    ]);
    _react.useEffect(()=>{
        if (editor && props.onReady) {
            props.onReady(editor);
            setTimeout(()=>{
                editor.refresh();
            }, 1);
        }
    }, [
        editor
    ]);
    _react.useEffect(()=>{
        props.sdk.access.can('create', 'Asset').then((value)=>{
            setCanUploadAssets(value);
        });
    }, []);
    _react.useEffect(()=>{
        if (editor) {
            editor.setReadOnly(!!props.isDisabled);
        }
    }, [
        editor,
        props.isDisabled
    ]);
    _react.useEffect(()=>{
        if (props.externalReset !== prevExternalReset.current) {
            prevExternalReset.current = props.externalReset;
            editor?.setContent(props.value ?? '');
        }
    }, [
        props.value,
        props.externalReset,
        editor
    ]);
    const isActionDisabled = editor === null || props.isDisabled || selectedTab !== 'editor';
    const direction = props.sdk.locales.direction[props.sdk.field.locale] ?? 'ltr';
    const actions = _react.useMemo(()=>{
        return (0, _MarkdownActions.createMarkdownActions)({
            sdk: props.sdk,
            editor,
            locale: props.sdk.field.locale
        });
    }, [
        editor
    ]);
    const openMarkdownHelp = _react.useCallback(()=>{
        (0, _CheatsheetModalDialog.openCheatsheetModal)(props.sdk.dialogs);
    }, []);
    return /*#__PURE__*/ _react.createElement("div", {
        className: styles.container,
        "data-test-id": "markdown-editor"
    }, /*#__PURE__*/ _react.createElement(_MarkdownTabs.MarkdownTabs, {
        active: selectedTab,
        onSelect: (tab)=>{
            if (props.enableTab) return;
            setSelectedTab(tab);
        },
        enableTab: props.enableTab
    }), /*#__PURE__*/ _react.createElement(_MarkdownToolbar.MarkdownToolbar, {
        mode: "default",
        disabled: isActionDisabled,
        canUploadAssets: canUploadAssets,
        actions: actions
    }), /*#__PURE__*/ _react.createElement(_MarkdownTextarea.MarkdownTextarea, {
        minHeight: props.minHeight,
        mode: "default",
        visible: selectedTab === 'editor',
        disabled: isActionDisabled,
        direction: direction,
        onReady: (editor)=>{
            editor.setContent(props.value ?? '');
            editor.setReadOnly(!!props.isDisabled);
            setEditor(editor);
            editor.events.onChange((value)=>{
                const trimmedValue = value.replace(/^\s+$/gm, '');
                props.saveValueToSDK(trimmedValue);
                setCurrentValue(value);
            });
        }
    }), selectedTab === 'preview' && /*#__PURE__*/ _react.createElement(_react.Suspense, {
        fallback: /*#__PURE__*/ _react.createElement(_MarkdownPreviewSkeleton.default, null)
    }, /*#__PURE__*/ _react.createElement(MarkdownPreview, {
        direction: direction,
        minHeight: props.minHeight,
        mode: "default",
        value: currentValue,
        previewComponents: props.previewComponents
    })), /*#__PURE__*/ _react.createElement(_MarkdownBottomBar.MarkdownBottomBar, null, /*#__PURE__*/ _react.createElement(_MarkdownBottomBar.MarkdownHelp, {
        mode: selectedTab,
        onClick: openMarkdownHelp
    })), /*#__PURE__*/ _react.createElement(_MarkdownConstraints.MarkdownConstraints, {
        sdk: props.sdk,
        value: currentValue
    }));
}
function MarkdownEditorConnected(props) {
    return /*#__PURE__*/ _react.createElement(_fieldeditorshared.FieldConnector, {
        debounce: 300,
        field: props.sdk.field,
        isInitiallyDisabled: props.isInitiallyDisabled,
        isDisabled: props.isDisabled
    }, ({ value, disabled, setValue, externalReset })=>/*#__PURE__*/ _react.createElement(MarkdownEditor, {
            ...props,
            value: value,
            isDisabled: disabled,
            saveValueToSDK: setValue,
            externalReset: externalReset
        }));
}
