"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    MarkdownBottomBar: function() {
        return MarkdownBottomBar;
    },
    MarkdownCounter: function() {
        return MarkdownCounter;
    },
    MarkdownHelp: function() {
        return MarkdownHelp;
    }
});
const _react = /*#__PURE__*/ _interop_require_wildcard(require("react"));
const _f36components = require("@contentful/f36-components");
const _f36tokens = /*#__PURE__*/ _interop_require_default(require("@contentful/f36-tokens"));
const _emotion = require("emotion");
function _interop_require_default(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
const SANITIZE_LINK = 'https://en.wikipedia.org/wiki/HTML_sanitization';
const styles = {
    root: (0, _emotion.css)({
        display: 'flex',
        justifyContent: 'space-between',
        background: _f36tokens.default.gray100,
        border: `1px solid ${_f36tokens.default.gray400}`,
        borderBottomLeftRadius: _f36tokens.default.borderRadiusSmall,
        borderBottomRightRadius: _f36tokens.default.borderRadiusSmall,
        padding: `${_f36tokens.default.spacingXs} ${_f36tokens.default.spacingS}`
    }),
    help: (0, _emotion.css)({
        color: _f36tokens.default.gray700,
        fontSize: _f36tokens.default.fontSizeS,
        '& button, & a': {
            fontSize: _f36tokens.default.fontSizeS,
            lineHeight: 'inherit'
        }
    })
};
function MarkdownCounter(props) {
    return /*#__PURE__*/ _react.createElement(_f36components.Paragraph, {
        marginBottom: "none",
        className: styles.help
    }, props.words, " ", props.words !== 1 ? 'words' : 'word', ", ", props.characters, ' ', props.characters !== 1 ? 'characters' : 'character');
}
function SanitizeMessage() {
    return /*#__PURE__*/ _react.createElement("span", null, "The preview of the content in this field will be sanitized.", ' ', /*#__PURE__*/ _react.createElement(_f36components.TextLink, {
        as: "a",
        target: "_blank",
        rel: "noopener noreferrer",
        href: SANITIZE_LINK
    }, "Learn more."));
}
function CheatSheetMessage({ onClick }) {
    return /*#__PURE__*/ _react.createElement("span", null, "Format your text like a pro with the", ' ', /*#__PURE__*/ _react.createElement(_f36components.TextLink, {
        as: "button",
        testId: "open-markdown-cheatsheet-button",
        onClick: onClick
    }, "markdown cheatsheet"), ".");
}
function MarkdownHelp(props) {
    let content;
    switch(props.mode){
        case 'preview':
            content = /*#__PURE__*/ _react.createElement(SanitizeMessage, null);
            break;
        case 'editor':
            content = /*#__PURE__*/ _react.createElement(CheatSheetMessage, {
                onClick: props.onClick
            });
            break;
        case 'zen':
            content = /*#__PURE__*/ _react.createElement(_f36components.Stack, {
                flexDirection: "column",
                spacing: "spacing2Xs",
                alignItems: "flex-start"
            }, /*#__PURE__*/ _react.createElement(CheatSheetMessage, {
                onClick: props.onClick
            }), /*#__PURE__*/ _react.createElement(SanitizeMessage, null));
            break;
        default:
            content = null;
            throw new Error(`Invalid HelpMode provided in MarkdownHelp: ${props.mode}`);
    }
    return /*#__PURE__*/ _react.createElement(_f36components.Paragraph, {
        marginBottom: "none",
        className: styles.help
    }, content);
}
function MarkdownBottomBar(props) {
    return /*#__PURE__*/ _react.createElement("div", {
        className: styles.root
    }, props.children);
}
