"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "MarkdownTabs", {
    enumerable: true,
    get: function() {
        return MarkdownTabs;
    }
});
const _react = /*#__PURE__*/ _interop_require_wildcard(require("react"));
const _f36tokens = /*#__PURE__*/ _interop_require_default(require("@contentful/f36-tokens"));
const _emotion = require("emotion");
function _interop_require_default(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
const styles = {
    root: (0, _emotion.css)({
        display: 'flex',
        zIndex: 10,
        flexDirection: 'row',
        justifyContent: 'flex-end',
        overflow: 'hidden',
        marginBottom: '-1px',
        fontSize: _f36tokens.default.fontSizeM
    }),
    tab: (0, _emotion.css)({
        cursor: 'pointer',
        color: _f36tokens.default.gray700,
        padding: _f36tokens.default.spacingXs,
        minWidth: '70px',
        border: `1px solid ${_f36tokens.default.gray400}`,
        borderTopLeftRadius: _f36tokens.default.borderRadiusSmall,
        borderTopRightRadius: _f36tokens.default.borderRadiusSmall,
        marginLeft: _f36tokens.default.spacingXs,
        textAlign: 'center',
        backgroundColor: _f36tokens.default.gray100,
        borderBottomColor: _f36tokens.default.gray100,
        outline: 'none',
        '&:focus': {
            boxShadow: _f36tokens.default.boxShadowHeavy
        },
        transition: `all ${_f36tokens.default.transitionEasingDefault} ${_f36tokens.default.transitionDurationShort}`
    }),
    inactiveTab: (0, _emotion.css)({
        background: _f36tokens.default.gray200,
        borderBottomColor: _f36tokens.default.gray400,
        '&:hover': {
            background: _f36tokens.default.gray300
        }
    }),
    disabledTab: (0, _emotion.css)({
        cursor: 'not-allowed',
        '&:hover': {
            background: _f36tokens.default.gray200,
            boxShadow: 'none'
        }
    })
};
function MarkdownTabItem(props) {
    return /*#__PURE__*/ _react.createElement("div", {
        className: (0, _emotion.cx)(styles.tab, {
            [styles.inactiveTab]: props.isActive === false,
            [styles.disabledTab]: props.isDisabled === true
        }),
        onClick: ()=>{
            props.onSelect(props.name);
        },
        onKeyDown: (e)=>{
            if (e.keyCode === 13) {
                props.onSelect(props.name);
            }
        },
        tabIndex: 0,
        role: "tab",
        "aria-controls": props.name,
        "aria-selected": props.isActive === true,
        "data-test-id": props.testId
    }, props.children);
}
function MarkdownTabs(props) {
    return /*#__PURE__*/ _react.createElement("div", {
        className: styles.root
    }, /*#__PURE__*/ _react.createElement(MarkdownTabItem, {
        name: "editor",
        onSelect: props.onSelect,
        isActive: props.active === 'editor',
        testId: "markdown-tab-md",
        isDisabled: props.enableTab && props.enableTab !== 'editor'
    }, "Editor"), /*#__PURE__*/ _react.createElement(MarkdownTabItem, {
        name: "preview",
        onSelect: props.onSelect,
        isActive: props.active === 'preview',
        testId: "markdown-tab-preview",
        isDisabled: props.enableTab && props.enableTab !== 'preview'
    }, "Preview"));
}
