"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "MarkdownTextarea", {
    enumerable: true,
    get: function() {
        return MarkdownTextarea;
    }
});
const _react = /*#__PURE__*/ _interop_require_wildcard(require("react"));
const _f36tokens = /*#__PURE__*/ _interop_require_default(require("@contentful/f36-tokens"));
const _emotion = require("emotion");
const _createMarkdownEditor = require("./createMarkdownEditor");
function _interop_require_default(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
const styles = {
    root: (0, _emotion.css)`
    border: 1px solid ${_f36tokens.default.gray400};
    border-width: 0 1px;
    overflow-y: auto;
    height: auto;
    min-height: 300px;

    .CodeMirror {
      height: auto;
      line-height: ${_f36tokens.default.lineHeightDefault};
    }
    .CodeMirror-lines {
      color: ${_f36tokens.default.gray700};
      padding: ${_f36tokens.default.spacingL};
    }
    .CodeMirror-code {
      font-family: ${_f36tokens.default.fontStackMonospace};
      font-size: ${_f36tokens.default.fontSizeM};
    }
    .CodeMirror-scroll {
      min-height: '6rem';
    }

    .cm-header {
      color: ${_f36tokens.default.gray900};
    }
    span.cm-variable-2 {
      color: ${_f36tokens.default.gray700};
    }
    .cm-header-1 {
      font-size: 1.9em;
    }
    .cm-header-2 {
      font-size: 1.75em;
    }
    .cm-header-3 {
      font-size: 1.6em;
    }
    .cm-header-4 {
      font-size: 1.45em;
    }
    .cm-header-5 {
      font-size: 1.3em;
    }
    .cm-header-6 {
      font-size: 1.15em;
    }

    span.cm-tag,
    span.cm-string,
    span.cm-attribute {
      color: ${_f36tokens.default.red600};
    }
    span.cm-string {
      text-decoration: none !important;
    }
    span.cm-quote,
    span.cm-comment {
      color: ${_f36tokens.default.gray600};
    }
    span.cm-link,
    span.cm-url {
      color: ${_f36tokens.default.blue500} !important;
    }
    span.cm-link {
      text-decoration: underline;
    }
  `,
    framed: (0, _emotion.css)({
        '.CodeMirror': {
            maxHeight: '500px'
        }
    }),
    zen: (0, _emotion.css)({
        border: 'none !important',
        '.CodeMirror-lines': {
            maxWidth: '650px',
            margin: '0 auto'
        }
    }),
    disabled: (0, _emotion.css)`
    .CodeMirror {
      background: ${_f36tokens.default.gray100};
      cursor: 'not-allowed';
    }
    .CodeMirror-cursors {
      visibility: hidden !important;
    }
    .CodeMirror-scroll,
    .CodeMirror-sizer,
    .CodeMirror-lines {
      cursor: not-allowed;
    }
  `
};
const MarkdownTextarea = /*#__PURE__*/ _react.default.memo((props)=>{
    const hostRef = (0, _react.useRef)(null);
    const [editor, setEditor] = (0, _react.useState)(null);
    (0, _react.useEffect)(()=>{
        if (hostRef.current) {
            setEditor((0, _createMarkdownEditor.createMarkdownEditor)(hostRef.current, Object.assign({}, {
                direction: props.direction,
                readOnly: true
            }, props.mode === 'zen' ? {
                fixedHeight: true,
                height: '100%'
            } : {}, props.minHeight !== undefined ? {
                height: props.minHeight
            } : {})));
        }
    }, []);
    (0, _react.useEffect)(()=>{
        if (editor) {
            props.onReady(editor);
        }
    }, [
        editor
    ]);
    const className = (0, _emotion.cx)(styles.root, props.minHeight !== undefined ? (0, _emotion.css)({
        minHeight: props.minHeight
    }) : undefined, props.mode === 'default' ? styles.framed : styles.zen, props.disabled && styles.disabled);
    return /*#__PURE__*/ _react.default.createElement("div", {
        className: className,
        ref: hostRef,
        "data-test-id": "markdown-textarea",
        style: {
            display: props.visible ? 'block' : 'none'
        }
    });
});
MarkdownTextarea.displayName = 'MarkdownTextarea';
