"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "createMarkdownEditor", {
    enumerable: true,
    get: function() {
        return createMarkdownEditor;
    }
});
const _CodeMirrorWrapper = /*#__PURE__*/ _interop_require_wildcard(require("./CodeMirrorWrapper"));
const _MarkdownCommands = /*#__PURE__*/ _interop_require_wildcard(require("./MarkdownCommands"));
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
function createMarkdownEditor(host, options) {
    const editor = _CodeMirrorWrapper.create(host, options);
    function wrapChange(fn) {
        return (e, ch)=>{
            fn(editor.getValue(), e, ch);
        };
    }
    const api = {
        actions: _MarkdownCommands.create(editor),
        history: {
            hasUndo: function() {
                return editor.getHistorySize('undo') > 0;
            },
            hasRedo: function() {
                return editor.getHistorySize('redo') > 0;
            }
        },
        events: {
            onScroll: function(fn) {
                editor.attachEvent('scroll', fn, 150);
            },
            onChange: function(fn) {
                editor.attachEvent('change', wrapChange(fn), 0);
            },
            onPaste: function(fn) {
                editor.attachEvent('paste', fn, 0);
            }
        },
        insert: editor.insertAtCursor,
        focus: editor.focus,
        getContent: editor.getValue,
        destroy: editor.destroy,
        setContent: editor.setValue,
        getSelectedText: editor.getSelectedText,
        usePrimarySelection: editor.usePrimarySelection,
        setReadOnly: editor.setReadOnly,
        selectBackwards: editor.selectBackwards,
        getCursor: editor.getCursor,
        setCursor: editor.setCursor,
        clear: ()=>editor.setValue(''),
        selectAll: editor.selectAll,
        setFullsize: editor.setFullsize,
        refresh: editor.refresh
    };
    editor.addKeyShortcuts({
        B: api.actions.bold,
        I: api.actions.italic
    });
    return api;
}
