"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    DefaultMarkdownToolbar: function() {
        return DefaultMarkdownToolbar;
    },
    MarkdownToolbar: function() {
        return MarkdownToolbar;
    },
    ZenMarkdownToolbar: function() {
        return ZenMarkdownToolbar;
    }
});
const _react = /*#__PURE__*/ _interop_require_wildcard(require("react"));
const _f36components = require("@contentful/f36-components");
const _f36icons = require("@contentful/f36-icons");
const _f36tokens = /*#__PURE__*/ _interop_require_default(require("@contentful/f36-tokens"));
const _emotion = require("emotion");
const _HeadingSelector = require("./HeadingSelector");
const _icons = /*#__PURE__*/ _interop_require_wildcard(require("./icons"));
const _InsertLinkSelector = require("./InsertLinkSelector");
function _interop_require_default(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
const styles = {
    root: (0, _emotion.css)({
        position: 'relative',
        zIndex: Number(_f36tokens.default.zIndexWorkbenchHeader),
        border: `1px solid ${_f36tokens.default.gray400}`,
        backgroundColor: _f36tokens.default.gray100,
        padding: _f36tokens.default.spacingXs,
        borderTopLeftRadius: _f36tokens.default.borderRadiusSmall,
        overflow: 'hidden'
    }),
    button: (0, _emotion.css)({
        height: '30px',
        width: '36px',
        marginLeft: _f36tokens.default.spacing2Xs,
        marginRight: _f36tokens.default.spacing2Xs
    }),
    icon: (0, _emotion.css)({
        fill: _f36tokens.default.gray700,
        verticalAlign: 'middle'
    }),
    zenButton: (0, _emotion.css)({
        marginLeft: _f36tokens.default.spacingXs
    }),
    zenButtonPressed: (0, _emotion.css)({
        backgroundColor: _f36tokens.default.gray400
    }),
    tooltip: (0, _emotion.css)({
        zIndex: Number(_f36tokens.default.zIndexTooltip)
    })
};
const ToolbarButton = /*#__PURE__*/ _react.forwardRef((props, ref)=>{
    const { tooltip, onClick, children, className, variant = 'transparent', tooltipPlace = 'top', isDisabled = false, ...otherProps } = props;
    return /*#__PURE__*/ _react.createElement(_f36components.Tooltip, {
        className: styles.tooltip,
        usePortal: true,
        placement: tooltipPlace,
        content: tooltip
    }, /*#__PURE__*/ _react.createElement(_f36components.IconButton, {
        ...otherProps,
        ref: ref,
        className: (0, _emotion.cx)(styles.button, className),
        isDisabled: isDisabled,
        onClick: onClick,
        variant: variant,
        size: "small",
        icon: children,
        "aria-label": tooltip
    }));
});
ToolbarButton.displayName = 'ToolbarButton';
function MainButtons(props) {
    const tooltipPlace = props.mode === 'zen' ? 'bottom' : 'top';
    return /*#__PURE__*/ _react.createElement(_react.Fragment, null, /*#__PURE__*/ _react.createElement(_HeadingSelector.HeadingSelector, {
        onSelect: (heading)=>{
            if (heading && props.actions.headings[heading]) {
                props.actions.headings[heading]();
            }
        }
    }, /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-heading",
        tooltip: "Headings",
        tooltipPlace: tooltipPlace
    }, /*#__PURE__*/ _react.createElement(_f36icons.HeadingIcon, {
        "aria-label": "Headings",
        className: styles.icon
    }))), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-bold",
        tooltip: "Bold",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.bold
    }, /*#__PURE__*/ _react.createElement(_f36icons.FormatBoldIcon, {
        "aria-label": "Bold",
        className: styles.icon
    })), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-italic",
        tooltip: "Italic",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.italic
    }, /*#__PURE__*/ _react.createElement(_f36icons.FormatItalicIcon, {
        "aria-label": "Italic",
        className: styles.icon
    })), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-quote",
        tooltip: "Quote",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.quote
    }, /*#__PURE__*/ _react.createElement(_f36icons.QuoteIcon, {
        "aria-label": "Quote",
        className: styles.icon
    })), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-ul",
        tooltip: "Unordered list",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.ul
    }, /*#__PURE__*/ _react.createElement(_f36icons.ListBulletedIcon, {
        "aria-label": "Unordered list",
        className: styles.icon
    })), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-ol",
        tooltip: "Ordered list",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.ol
    }, /*#__PURE__*/ _react.createElement(_f36icons.ListNumberedIcon, {
        "aria-label": "Ordered list",
        className: styles.icon
    })), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-link",
        tooltip: "Link",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.insertLink
    }, /*#__PURE__*/ _react.createElement(_f36icons.LinkIcon, {
        "aria-label": "Link",
        className: styles.icon
    })));
}
function AdditionalButtons(props) {
    const tooltipPlace = props.mode === 'zen' ? 'bottom' : 'top';
    return /*#__PURE__*/ _react.createElement(_react.Fragment, null, /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-strike",
        tooltip: "Strike out",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.strike
    }, /*#__PURE__*/ _react.createElement(_icons.Strikethrough, {
        label: "Strike out",
        className: styles.icon
    })), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-code",
        tooltip: "Code block",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.code
    }, /*#__PURE__*/ _react.createElement(_f36icons.CodeIcon, {
        "aria-label": "Code block",
        className: styles.icon
    })), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-hr",
        tooltip: "Horizontal rule",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.hr
    }, /*#__PURE__*/ _react.createElement(_f36icons.HorizontalRuleIcon, {
        "aria-label": "Horizontal rule",
        className: styles.icon
    })), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-indent",
        tooltip: "Increase indentation",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.indent
    }, /*#__PURE__*/ _react.createElement(_icons.Indent, {
        label: "Increase indentation",
        className: styles.icon
    })), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-dedent",
        tooltip: "Decrease indentation",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.dedent
    }, /*#__PURE__*/ _react.createElement(_icons.Dedent, {
        label: "Decrease indentation",
        className: styles.icon
    })), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-embed",
        tooltip: "Embed external content",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.embedExternalContent
    }, /*#__PURE__*/ _react.createElement(_icons.Cubes, {
        label: "Embed external content",
        className: styles.icon
    })), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-table",
        tooltip: "Insert table",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.insertTable
    }, /*#__PURE__*/ _react.createElement(_icons.Table, {
        label: "Insert table",
        className: styles.icon
    })), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-special",
        tooltip: "Insert special character",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.insertSpecialCharacter
    }, /*#__PURE__*/ _react.createElement(_icons.SpecialChar, {
        label: "Insert special character",
        className: styles.icon
    })), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-organizeLinks",
        tooltip: "Organize links",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.organizeLinks
    }, /*#__PURE__*/ _react.createElement(_icons.OrgLinks, {
        label: "Organize links",
        className: styles.icon
    })), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-undo",
        tooltip: "Undo",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.history.undo
    }, /*#__PURE__*/ _react.createElement(_icons.Undo, {
        label: "Undo",
        className: styles.icon
    })), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-redo",
        tooltip: "Redo",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.history.redo
    }, /*#__PURE__*/ _react.createElement(_icons.Redo, {
        label: "Redo",
        className: styles.icon
    })));
}
function DefaultMarkdownToolbar(props) {
    const [showAdditional, setShowAdditional] = _react.useState(false);
    return /*#__PURE__*/ _react.createElement("div", {
        className: styles.root
    }, /*#__PURE__*/ _react.createElement(_f36components.Flex, {
        justifyContent: "space-between",
        flexWrap: "wrap"
    }, /*#__PURE__*/ _react.createElement(_f36components.Flex, {
        flexWrap: "wrap"
    }, /*#__PURE__*/ _react.createElement(MainButtons, props), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-toggle-additional",
        tooltip: showAdditional ? 'Hide additional actions' : 'More actions',
        onClick: ()=>{
            setShowAdditional(!showAdditional);
        }
    }, /*#__PURE__*/ _react.createElement(_f36icons.MoreHorizontalIcon, {
        className: styles.icon
    }))), /*#__PURE__*/ _react.createElement(_f36components.Flex, null, /*#__PURE__*/ _react.createElement(_InsertLinkSelector.InsertLinkSelector, {
        disabled: props.disabled,
        onSelectExisting: props.actions.linkExistingMedia,
        onAddNew: props.actions.addNewMedia,
        canAddNew: props.canUploadAssets
    }), /*#__PURE__*/ _react.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-zen",
        variant: "secondary",
        onClick: props.actions.openZenMode,
        className: styles.zenButton,
        tooltip: "Expand"
    }, /*#__PURE__*/ _react.createElement(_icons.Zen, {
        label: "Expand",
        className: styles.icon
    })))), showAdditional && /*#__PURE__*/ _react.createElement(_f36components.Flex, {
        justifyContent: "space-between",
        marginTop: "spacingXs"
    }, /*#__PURE__*/ _react.createElement(_f36components.Flex, null, /*#__PURE__*/ _react.createElement(AdditionalButtons, props))));
}
function ZenMarkdownToolbar(props) {
    return /*#__PURE__*/ _react.createElement("div", {
        className: styles.root
    }, /*#__PURE__*/ _react.createElement(_f36components.Flex, {
        justifyContent: "space-between",
        alignItems: "flex-start"
    }, /*#__PURE__*/ _react.createElement(_f36components.Flex, {
        flexWrap: "wrap"
    }, /*#__PURE__*/ _react.createElement(MainButtons, props), /*#__PURE__*/ _react.createElement(AdditionalButtons, props)), /*#__PURE__*/ _react.createElement(_f36components.Flex, null, /*#__PURE__*/ _react.createElement(_InsertLinkSelector.InsertLinkSelector, {
        disabled: props.disabled,
        onSelectExisting: props.actions.linkExistingMedia,
        onAddNew: props.actions.addNewMedia,
        canAddNew: props.canUploadAssets
    }), /*#__PURE__*/ _react.createElement(_f36components.IconButton, {
        testId: "markdown-action-button-zen-close",
        variant: "secondary",
        size: "small",
        className: (0, _emotion.cx)(styles.zenButton, styles.zenButtonPressed),
        onClick: ()=>{
            props.actions.closeZenMode();
        },
        icon: /*#__PURE__*/ _react.createElement(_icons.Zen, {
            label: "Collapse",
            className: styles.icon
        }),
        "aria-label": "Collapse"
    }))));
}
const MarkdownToolbar = /*#__PURE__*/ _react.memo((props)=>{
    if (props.mode === 'zen') {
        return /*#__PURE__*/ _react.createElement(ZenMarkdownToolbar, props);
    }
    return /*#__PURE__*/ _react.createElement(DefaultMarkdownToolbar, props);
});
MarkdownToolbar.displayName = 'MarkdownToolbar';
