"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    EmbedExternalContentModal: function() {
        return EmbedExternalContentModal;
    },
    openEmbedExternalContentDialog: function() {
        return openEmbedExternalContentDialog;
    }
});
const _react = /*#__PURE__*/ _interop_require_wildcard(require("react"));
const _f36components = require("@contentful/f36-components");
const _f36tokens = /*#__PURE__*/ _interop_require_default(require("@contentful/f36-tokens"));
const _emotion = require("emotion");
const _types = require("../types");
const _isValidUrl = require("../utils/isValidUrl");
function _interop_require_default(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
const styles = {
    widthFiledGroup: (0, _emotion.css)({
        display: 'flex',
        flexWrap: 'nowrap',
        alignItems: 'flex-start'
    }),
    radioButtonGroup: (0, _emotion.css)({
        display: 'inline-flex',
        alignItems: 'flex-start',
        paddingTop: _f36tokens.default.spacingXl
    }),
    radioButton: (0, _emotion.css)({
        marginLeft: _f36tokens.default.spacingM
    })
};
const makeEmbedlyLink = ({ url, width, selectedUnit, attachSocial })=>{
    const s = {
        percent: '%',
        px: 'px'
    };
    return [
        '<a href="' + url + '" class="embedly-card" ',
        'data-card-width="' + width + s[selectedUnit] + '" ',
        'data-card-controls="' + (attachSocial ? '1' : '0') + '"',
        '>Embedded content: ' + url + '</a>'
    ].join('');
};
const isWidthValid = (width, unit)=>unit === 'percent' ? width <= 100 : true;
const EmbedExternalContentModal = ({ onClose })=>{
    const mainInputRef = (0, _react.useRef)(null);
    const [url, setUrl] = (0, _react.useState)('https://');
    const [selectedUnit, setUnit] = (0, _react.useState)('percent');
    const [urlIsValid, setUrlValidity] = (0, _react.useState)(true);
    const [width, setWidth] = (0, _react.useState)('100');
    const [attachSocial, setAttachSocial] = (0, _react.useState)(false);
    (0, _react.useEffect)(()=>{
        if (mainInputRef.current?.focus) {
            mainInputRef.current.focus();
        }
    }, [
        mainInputRef
    ]);
    return /*#__PURE__*/ _react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/ _react.default.createElement(_f36components.ModalContent, {
        testId: "embed-external-dialog"
    }, /*#__PURE__*/ _react.default.createElement(_f36components.Form, null, /*#__PURE__*/ _react.default.createElement(_f36components.FormControl, {
        id: "external-link-url-field",
        isRequired: true,
        isInvalid: !urlIsValid
    }, /*#__PURE__*/ _react.default.createElement(_f36components.FormControl.Label, null, "Content URL"), /*#__PURE__*/ _react.default.createElement(_f36components.TextInput, {
        name: "external-link-url",
        value: url,
        onChange: (e)=>{
            const value = e.target.value;
            setUrl(value);
            setUrlValidity((0, _isValidUrl.isValidUrl)(value));
        },
        testId: "external-link-url-field",
        placeholder: "https://example.com",
        ref: mainInputRef
    }), /*#__PURE__*/ _react.default.createElement(_f36components.FormControl.HelpText, null, "Include protocol (e.g. https://)"), !urlIsValid && /*#__PURE__*/ _react.default.createElement(_f36components.FormControl.ValidationMessage, null, "URL is invalid")), /*#__PURE__*/ _react.default.createElement(_f36components.TextLink, {
        href: "http://embed.ly/providers",
        target: "_blank",
        rel: "noopener noreferrer"
    }, "Supported sources"), /*#__PURE__*/ _react.default.createElement("div", {
        className: styles.widthFiledGroup
    }, /*#__PURE__*/ _react.default.createElement(_f36components.FormControl, {
        id: "embedded-content-width",
        isRequired: true,
        isInvalid: !isWidthValid(Number(width), selectedUnit)
    }, /*#__PURE__*/ _react.default.createElement(_f36components.FormControl.Label, null, "Width"), /*#__PURE__*/ _react.default.createElement(_f36components.TextInput, {
        value: width,
        name: "embedded-content-width",
        testId: "embedded-content-width",
        type: "number",
        width: "small",
        onChange: (e)=>setWidth(e.target.value)
    }), !isWidthValid(Number(width), selectedUnit) && /*#__PURE__*/ _react.default.createElement(_f36components.FormControl.ValidationMessage, null, "Should be equal or less then 100")), /*#__PURE__*/ _react.default.createElement("div", {
        className: styles.radioButtonGroup
    }, /*#__PURE__*/ _react.default.createElement(_f36components.Radio, {
        id: "unit-option-percent",
        value: "percent",
        isChecked: selectedUnit === 'percent',
        onChange: ()=>setUnit('percent'),
        className: styles.radioButton
    }, "percent"), /*#__PURE__*/ _react.default.createElement(_f36components.Radio, {
        id: "unit-option-pixels",
        value: "pixels",
        isChecked: selectedUnit === 'px',
        onChange: ()=>setUnit('px'),
        className: styles.radioButton
    }, "pixels"))), /*#__PURE__*/ _react.default.createElement(_f36components.Checkbox, {
        id: "attach-social-checkbox",
        name: "attach-social-checkbox",
        value: "Yes",
        isChecked: attachSocial,
        onChange: ()=>setAttachSocial(!attachSocial),
        testId: "attach-social-checkbox"
    }, "Attach social sharing links to this element"), /*#__PURE__*/ _react.default.createElement(_f36components.Text, {
        as: "p",
        fontColor: "gray500",
        marginTop: "spacingXs"
    }, "To enable this embedded content in your application make sure to add the ", /*#__PURE__*/ _react.default.createElement(_f36components.TextLink, {
        href: "http://embed.ly/docs/products/cards",
        target: "_blank",
        rel: "noopener noreferrer"
    }, "Embedly's platform.js"), " on your development environment"))), /*#__PURE__*/ _react.default.createElement(_f36components.ModalControls, null, /*#__PURE__*/ _react.default.createElement(_f36components.Button, {
        testId: "emded-external-cancel",
        onClick: ()=>onClose(false),
        variant: "secondary",
        size: "small"
    }, "Cancel"), /*#__PURE__*/ _react.default.createElement(_f36components.Button, {
        testId: "embed-external-confirm",
        onClick: ()=>onClose(makeEmbedlyLink({
                url,
                width: Number(width),
                selectedUnit,
                attachSocial
            })),
        variant: "positive",
        size: "small"
    }, "Insert")));
};
const openEmbedExternalContentDialog = (dialogs)=>{
    return dialogs.openCurrent({
        title: 'Embed external content',
        width: 'large',
        minHeight: '435px',
        shouldCloseOnEscapePress: true,
        shouldCloseOnOverlayClick: true,
        parameters: {
            type: _types.MarkdownDialogType.embedExternalContent
        }
    });
};
