"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    InsertLinkModal: function() {
        return InsertLinkModal;
    },
    openInsertLinkDialog: function() {
        return openInsertLinkDialog;
    }
});
const _react = /*#__PURE__*/ _interop_require_wildcard(require("react"));
const _f36components = require("@contentful/f36-components");
const _types = require("../types");
const _isValidUrl = require("../utils/isValidUrl");
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
const InsertLinkModal = ({ selectedText, onClose })=>{
    const mainInputRef = (0, _react.useRef)(null);
    const [text, setText] = (0, _react.useState)(selectedText || '');
    const [url, setUrl] = (0, _react.useState)('');
    const [touched, setTouched] = (0, _react.useState)(false);
    const [title, setTitle] = (0, _react.useState)('');
    const onInsert = (values)=>onClose(values);
    const urlIsValid = (0, _isValidUrl.isValidUrl)(url);
    (0, _react.useEffect)(()=>{
        if (mainInputRef?.current?.focus) {
            mainInputRef.current.focus();
        }
    }, [
        mainInputRef
    ]);
    return /*#__PURE__*/ _react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/ _react.default.createElement(_f36components.ModalContent, {
        testId: "insert-link-modal"
    }, /*#__PURE__*/ _react.default.createElement(_f36components.Form, {
        onSubmit: ()=>onInsert({
                url,
                text,
                title
            })
    }, /*#__PURE__*/ _react.default.createElement(_f36components.FormControl, {
        id: "link-text-field",
        isDisabled: Boolean(selectedText)
    }, /*#__PURE__*/ _react.default.createElement(_f36components.FormControl.Label, null, "Link text"), /*#__PURE__*/ _react.default.createElement(_f36components.TextInput, {
        name: "link-text",
        value: text,
        onChange: (e)=>{
            setText(e.target.value);
        },
        testId: "link-text-field"
    })), /*#__PURE__*/ _react.default.createElement(_f36components.FormControl, {
        id: "target-url-field",
        isInvalid: touched && !urlIsValid
    }, /*#__PURE__*/ _react.default.createElement(_f36components.FormControl.Label, null, "Target URL"), /*#__PURE__*/ _react.default.createElement(_f36components.TextInput, {
        name: "target-url",
        value: url,
        onChange: (e)=>{
            setUrl(e.target.value);
            setTouched(true);
        },
        placeholder: "https://",
        maxLength: 2100,
        testId: "target-url-field",
        ref: mainInputRef
    }), /*#__PURE__*/ _react.default.createElement(_f36components.FormControl.HelpText, null, "Include protocol (e.g. https://)"), touched && !urlIsValid && /*#__PURE__*/ _react.default.createElement(_f36components.FormControl.ValidationMessage, null, "Invalid URL")), /*#__PURE__*/ _react.default.createElement(_f36components.FormControl, {
        id: "link-title-field"
    }, /*#__PURE__*/ _react.default.createElement(_f36components.FormControl.Label, null, "Link title"), /*#__PURE__*/ _react.default.createElement(_f36components.TextInput, {
        name: "link-title",
        value: title,
        onChange: (e)=>{
            setTitle(e.target.value);
        },
        testId: "link-title-field"
    }), /*#__PURE__*/ _react.default.createElement(_f36components.FormControl.HelpText, null, "Extra link information, usually shown as a tooltip on mouse hover")))), /*#__PURE__*/ _react.default.createElement(_f36components.ModalControls, null, /*#__PURE__*/ _react.default.createElement(_f36components.Button, {
        testId: "insert-link-cancel",
        onClick: ()=>onClose(false),
        variant: "secondary",
        size: "small"
    }, "Cancel"), /*#__PURE__*/ _react.default.createElement(_f36components.Button, {
        testId: "insert-link-confirm",
        onClick: ()=>{
            onInsert({
                url,
                text,
                title
            });
        },
        isDisabled: !urlIsValid,
        variant: "positive",
        size: "small"
    }, "Insert")));
};
const openInsertLinkDialog = (dialogs, params)=>{
    return dialogs.openCurrent({
        title: 'Insert link',
        width: 'large',
        minHeight: '410px',
        shouldCloseOnEscapePress: true,
        shouldCloseOnOverlayClick: true,
        parameters: {
            type: _types.MarkdownDialogType.insertLink,
            ...params
        }
    });
};
