"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    ZenModeModalDialog: function() {
        return ZenModeModalDialog;
    },
    openZenMode: function() {
        return openZenMode;
    }
});
const _react = /*#__PURE__*/ _interop_require_wildcard(require("react"));
const _f36components = require("@contentful/f36-components");
const _f36icons = require("@contentful/f36-icons");
const _f36tokens = /*#__PURE__*/ _interop_require_default(require("@contentful/f36-tokens"));
const _emotion = require("emotion");
const _MarkdownBottomBar = require("../components/MarkdownBottomBar");
const _MarkdownPreviewSkeleton = /*#__PURE__*/ _interop_require_default(require("../components/MarkdownPreviewSkeleton"));
const _MarkdownTextarea = require("../components/MarkdownTextarea/MarkdownTextarea");
const _MarkdownToolbar = require("../components/MarkdownToolbar");
const _CheatsheetModalDialog = require("../dialogs/CheatsheetModalDialog");
const _MarkdownActions = require("../MarkdownActions");
const _types = require("../types");
function _interop_require_default(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
const MarkdownPreview = /*#__PURE__*/ _react.lazy(()=>Promise.resolve().then(()=>/*#__PURE__*/ _interop_require_wildcard(require("../components/MarkdownPreview"))));
const styles = {
    root: (0, _emotion.css)({
        display: 'grid',
        gridTemplateRows: 'min-content 1fr min-content',
        gridTemplateColumns: '1fr 1px 1fr',
        height: '85vh'
    }),
    topSplit: (0, _emotion.css)({
        gridRow: '1 / 2',
        gridColumn: '1 / 4'
    }),
    bottomSplit: (0, _emotion.css)({
        gridRow: '3 / 4',
        gridColumn: '1 / 4'
    }),
    editorSplit: (0, _emotion.css)({
        gridRow: '2 / 3',
        gridColumn: '1 / 2',
        overflowY: 'scroll'
    }),
    editorSplitFullscreen: (0, _emotion.css)({
        gridRow: '2 / 3',
        gridColumn: '1 / 4',
        overflowY: 'scroll'
    }),
    previewSplit: (0, _emotion.css)({
        gridRow: '2 / 3',
        gridColumn: '3 / 4',
        overflowY: 'scroll'
    }),
    separator: (0, _emotion.css)({
        gridRow: '2 / 3',
        gridColumn: '2 / 3',
        backgroundColor: _f36tokens.default.gray400,
        width: '1px'
    }),
    button: (0, _emotion.css)({
        cursor: 'pointer',
        zIndex: 105,
        height: '30px',
        backgroundColor: _f36tokens.default.gray100,
        border: `1px solid ${_f36tokens.default.gray400}`,
        padding: 0
    }),
    hideButton: (0, _emotion.css)({
        gridRow: '2 / 3',
        gridColumn: '2 / 3',
        justifySelf: 'end',
        alignSelf: 'center'
    }),
    showButton: (0, _emotion.css)({
        gridRow: '2 / 3',
        gridColumn: '3 / 4',
        justifySelf: 'end',
        alignSelf: 'center'
    }),
    icon: (0, _emotion.css)({
        verticalAlign: 'middle'
    })
};
const ZenModeModalDialog = (props)=>{
    const [currentValue, setCurrentValue] = _react.useState(props.initialValue ?? '');
    const [showPreview, setShowPreview] = _react.useState(true);
    const [editor, setEditor] = _react.useState(null);
    _react.useEffect(()=>{
        props.sdk?.window?.updateHeight('100%');
    }, []);
    _react.useEffect(()=>{
        setTimeout(()=>{
            editor?.setFullsize();
            editor?.refresh();
        }, 150);
    }, [
        editor
    ]);
    const actions = _react.useMemo(()=>{
        return (0, _MarkdownActions.createMarkdownActions)({
            sdk: props.sdk,
            editor,
            locale: props.locale
        });
    }, [
        editor
    ]);
    actions.closeZenMode = ()=>{
        props.onClose({
            value: currentValue,
            cursor: editor?.getCursor()
        });
    };
    const direction = props.sdk.locales.direction[props.locale] ?? 'ltr';
    return /*#__PURE__*/ _react.createElement(_f36components.Grid, {
        className: styles.root,
        "data-test-id": "zen-mode-markdown-editor"
    }, /*#__PURE__*/ _react.createElement(_f36components.Grid.Item, {
        className: styles.topSplit
    }, /*#__PURE__*/ _react.createElement(_MarkdownToolbar.MarkdownToolbar, {
        mode: "zen",
        disabled: false,
        canUploadAssets: false,
        actions: actions
    })), /*#__PURE__*/ _react.createElement(_f36components.Grid.Item, {
        className: (0, _emotion.cx)(styles.editorSplit, {
            [styles.editorSplitFullscreen]: showPreview === false
        })
    }, /*#__PURE__*/ _react.createElement(_MarkdownTextarea.MarkdownTextarea, {
        mode: "zen",
        visible: true,
        disabled: false,
        direction: direction,
        onReady: (editor)=>{
            editor.setContent(props.initialValue ?? '');
            editor.setReadOnly(false);
            setEditor(editor);
            editor.focus();
            editor.events.onChange((value)=>{
                setCurrentValue(value);
                props.saveValueToSDK(value);
            });
        }
    })), showPreview && /*#__PURE__*/ _react.createElement(_f36components.Grid.Item, {
        className: styles.previewSplit
    }, /*#__PURE__*/ _react.createElement(_react.Suspense, {
        fallback: /*#__PURE__*/ _react.createElement(_MarkdownPreviewSkeleton.default, null)
    }, /*#__PURE__*/ _react.createElement(MarkdownPreview, {
        direction: direction,
        mode: "zen",
        value: currentValue,
        previewComponents: props.previewComponents
    }))), showPreview && /*#__PURE__*/ _react.createElement(_f36components.Grid.Item, {
        className: styles.separator
    }), showPreview && /*#__PURE__*/ _react.createElement("button", {
        className: (0, _emotion.cx)(styles.button, styles.hideButton),
        "aria-label": "Hide preview",
        onClick: ()=>{
            setShowPreview(false);
        }
    }, /*#__PURE__*/ _react.createElement(_f36icons.ChevronRightIcon, {
        variant: "muted",
        size: "tiny",
        className: styles.icon
    })), !showPreview && /*#__PURE__*/ _react.createElement("button", {
        className: (0, _emotion.cx)(styles.button, styles.showButton),
        "aria-label": "Show preview",
        onClick: ()=>{
            setShowPreview(true);
        }
    }, /*#__PURE__*/ _react.createElement(_f36icons.ChevronLeftIcon, {
        variant: "muted",
        size: "tiny",
        className: styles.icon
    })), /*#__PURE__*/ _react.createElement(_f36components.Grid.Item, {
        className: styles.bottomSplit
    }, /*#__PURE__*/ _react.createElement(_MarkdownBottomBar.MarkdownBottomBar, null, /*#__PURE__*/ _react.createElement(_MarkdownBottomBar.MarkdownHelp, {
        mode: "zen",
        onClick: ()=>{
            (0, _CheatsheetModalDialog.openCheatsheetModal)(props.sdk.dialogs);
        }
    }))));
};
const openZenMode = (dialogs, options)=>{
    return dialogs.openCurrent({
        width: 'fullWidth',
        shouldCloseOnEscapePress: false,
        shouldCloseOnOverlayClick: true,
        parameters: {
            type: _types.MarkdownDialogType.zenMode,
            initialValue: options.initialValue,
            locale: options.locale
        }
    });
};
