"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "openMarkdownDialog", {
    enumerable: true,
    get: function() {
        return openMarkdownDialog;
    }
});
const _react = /*#__PURE__*/ _interop_require_wildcard(require("react"));
const _fieldeditorshared = require("@contentful/field-editor-shared");
const _types = require("../types");
const _CheatsheetModalDialog = require("./CheatsheetModalDialog");
const _ConfirmInsertAssetModalDialog = require("./ConfirmInsertAssetModalDialog");
const _EmdebExternalContentDialog = require("./EmdebExternalContentDialog");
const _InsertLinkModalDialog = require("./InsertLinkModalDialog");
const _InsertTableModalDialog = require("./InsertTableModalDialog");
const _SpecialCharacterModalDialog = require("./SpecialCharacterModalDialog");
const _ZenModeModalDialog = require("./ZenModeModalDialog");
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
const openMarkdownDialog = (sdk, previewComponents)=>(options)=>{
        if (options.parameters?.type === _types.MarkdownDialogType.cheatsheet) {
            return _fieldeditorshared.ModalDialogLauncher.openDialog(options, ()=>{
                return /*#__PURE__*/ _react.createElement(_CheatsheetModalDialog.CheatsheetModalDialog, null);
            });
        } else if (options.parameters?.type === _types.MarkdownDialogType.insertLink) {
            const selectedText = options.parameters.selectedText;
            return _fieldeditorshared.ModalDialogLauncher.openDialog(options, ({ onClose })=>{
                return /*#__PURE__*/ _react.createElement(_InsertLinkModalDialog.InsertLinkModal, {
                    selectedText: selectedText,
                    onClose: onClose
                });
            });
        } else if (options.parameters?.type === _types.MarkdownDialogType.insertSpecialCharacter) {
            return _fieldeditorshared.ModalDialogLauncher.openDialog(options, ({ onClose })=>{
                return /*#__PURE__*/ _react.createElement(_SpecialCharacterModalDialog.SpecialCharacterModalDialog, {
                    onClose: onClose
                });
            });
        } else if (options.parameters?.type === _types.MarkdownDialogType.insertTable) {
            return _fieldeditorshared.ModalDialogLauncher.openDialog(options, ({ onClose })=>{
                return /*#__PURE__*/ _react.createElement(_InsertTableModalDialog.InsertTableModal, {
                    onClose: onClose
                });
            });
        } else if (options.parameters?.type === _types.MarkdownDialogType.embedExternalContent) {
            return _fieldeditorshared.ModalDialogLauncher.openDialog(options, ({ onClose })=>{
                return /*#__PURE__*/ _react.createElement(_EmdebExternalContentDialog.EmbedExternalContentModal, {
                    onClose: onClose
                });
            });
        } else if (options.parameters?.type === _types.MarkdownDialogType.confirmInsertAsset) {
            const locale = options.parameters.locale;
            const assets = options.parameters.assets;
            return _fieldeditorshared.ModalDialogLauncher.openDialog(options, ({ onClose })=>{
                return /*#__PURE__*/ _react.createElement(_ConfirmInsertAssetModalDialog.ConfirmInsertAssetModalDialog, {
                    onClose: onClose,
                    locale: locale,
                    assets: assets
                });
            });
        } else if (options.parameters?.type === _types.MarkdownDialogType.zenMode) {
            const initialValue = options.parameters.initialValue;
            const locale = options.parameters.locale;
            return _fieldeditorshared.ModalDialogLauncher.openDialog(options, ({ onClose })=>{
                return /*#__PURE__*/ _react.createElement(_ZenModeModalDialog.ZenModeModalDialog, {
                    saveValueToSDK: (value)=>{
                        if (value) {
                            return sdk?.field?.setValue(value);
                        }
                        return sdk?.field?.removeValue();
                    },
                    onClose: onClose,
                    initialValue: initialValue,
                    locale: locale,
                    sdk: sdk,
                    previewComponents: previewComponents
                });
            });
        }
        return Promise.reject();
    };
