"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    insertAssetLinks: function() {
        return insertAssetLinks;
    },
    replaceAssetDomain: function() {
        return replaceAssetDomain;
    }
});
const _get = /*#__PURE__*/ _interop_require_default(require("lodash/get"));
const _isObject = /*#__PURE__*/ _interop_require_default(require("lodash/isObject"));
function _interop_require_default(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function normalizeWhiteSpace(str) {
    if (str) {
        return str.trim().replace(/\s{2,}/g, ' ');
    } else {
        return str;
    }
}
function removeExtension(str) {
    return str.replace(/\.\w+$/g, '');
}
function fileNameToTitle(str) {
    return normalizeWhiteSpace(removeExtension(str).replace(/_/g, ' '));
}
function replaceAssetDomain(fileUrl) {
    const assetDomainMap = {
        images: 'images.ctfassets.net',
        assets: 'assets.ctfassets.net',
        downloads: 'downloads.ctfassets.net',
        videos: 'videos.ctfassets.net'
    };
    return fileUrl.replace(/(images|assets|downloads|videos).contentful.com/, (_, p1)=>{
        return assetDomainMap[p1];
    });
}
function makeAssetLink(asset, { localeCode, fallbackCode, defaultLocaleCode }) {
    const localizedFile = (0, _get.default)(asset, [
        'fields',
        'file',
        localeCode
    ]);
    const fallbackFile = fallbackCode ? (0, _get.default)(asset, [
        'fields',
        'file',
        fallbackCode
    ]) : null;
    const defaultFile = (0, _get.default)(asset, [
        'fields',
        'file',
        defaultLocaleCode
    ]);
    const file = localizedFile || fallbackFile || defaultFile;
    if ((0, _isObject.default)(file) && file.url) {
        const title = (0, _get.default)(asset, [
            'fields',
            'title',
            localeCode
        ]) || (0, _get.default)(asset, [
            'fields',
            'title',
            fallbackCode || ''
        ]) || (0, _get.default)(asset, [
            'fields',
            'title',
            defaultLocaleCode
        ]) || fileNameToTitle(file.fileName);
        const fileUrl = replaceAssetDomain(file.url);
        return {
            title,
            asset,
            url: fileUrl,
            isLocalized: Boolean(localizedFile),
            isFallback: Boolean(fallbackFile),
            asMarkdown: `![${title}](${fileUrl})`
        };
    } else {
        return null;
    }
}
async function insertAssetLinks(assets, locales) {
    const otherLocales = assets.filter((asset)=>{
        return !(0, _get.default)(asset, [
            'fields',
            'file',
            locales.localeCode
        ]);
    });
    const linksWithMeta = assets.map((asset)=>makeAssetLink(asset, locales)).filter((asset)=>asset !== null);
    if (otherLocales.length > 0) {
        const fallbackAssets = linksWithMeta.filter(({ isLocalized })=>!isLocalized).map(({ title, isFallback, asset })=>{
            const code = isFallback ? locales.fallbackCode : locales.defaultLocaleCode;
            return {
                title,
                thumbnailUrl: asset.fields.file[code].url,
                thumbnailAltText: title,
                description: isFallback ? `Fallback locale (${code})` : `Default locale (${code})`,
                asset: asset
            };
        });
        return {
            fallbacks: fallbackAssets,
            links: linksWithMeta
        };
    }
    return {
        links: linksWithMeta
    };
}
