"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        enumerable: true,
        get: all[name]
    });
}
_export(exports, {
    convertInlineToRef: function() {
        return convertInlineToRef;
    },
    findInline: function() {
        return findInline;
    },
    findLabels: function() {
        return findLabels;
    },
    findMaxLabelId: function() {
        return findMaxLabelId;
    },
    findRefs: function() {
        return findRefs;
    },
    rewriteRefs: function() {
        return rewriteRefs;
    }
});
const _extend = /*#__PURE__*/ _interop_require_default(require("lodash/extend"));
const _isObject = /*#__PURE__*/ _interop_require_default(require("lodash/isObject"));
const _max = /*#__PURE__*/ _interop_require_default(require("lodash/max"));
const _isFinite = /*#__PURE__*/ _interop_require_default(require("lodash/isFinite"));
const _forEach = /*#__PURE__*/ _interop_require_default(require("lodash/forEach"));
function _interop_require_default(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
function extractTitle(title) {
    title = title || '';
    title = title.replace(/^ *('|"|\()*/, '');
    title = title.replace(/('|"|\))* *$/, '');
    return title;
}
function head(text) {
    return text.split(' ').shift();
}
function tail(text) {
    const segments = text.split(' ');
    segments.shift();
    return segments.join(' ');
}
const PROCESSORS = {
    inline: function(match) {
        return {
            match: match[0],
            text: match[1],
            href: head(match[2]),
            title: extractTitle(tail(match[2]))
        };
    },
    ref: function(match) {
        return {
            match: match[0],
            text: match[1],
            id: match[2]
        };
    },
    label: function(match) {
        return {
            match: match[0],
            id: match[1],
            href: head(match[2]),
            title: extractTitle(tail(match[2]))
        };
    }
};
const REGEXS = {
    inline: /\[([^\r\n[\]]+)]\(([^\r\n)]+)\)/,
    ref: /\[([^\r\n[\]]+)] ?\[([^\r\n[\]]+)]/,
    label: /^ {0,3}\[([^\r\n[\]]+)]:\s+(.+)$/
};
const findInline = makeFinder('inline');
const findRefs = makeFinder('ref');
const findLabels = makeFinder('label');
function convertInlineToRef(text) {
    let id = findMaxLabelId(text);
    (0, _forEach.default)(findInline(text), (inline)=>{
        id += 1;
        text = text.replace(inline.match, buildRef(inline, id));
        text += '\n' + buildLabel(inline, id);
    });
    return text;
}
function mergeLabels(text) {
    const byHref = {};
    const byOldId = {};
    (0, _forEach.default)(findLabels(text), (label)=>{
        const alreadyAdded = byHref[label.href];
        const current = (0, _extend.default)({}, label);
        if (!alreadyAdded) {
            byHref[current.href] = current;
        } else if (hasTitle(current) && !hasTitle(alreadyAdded)) {
            alreadyAdded.title = current.title;
        }
        byOldId[current.id] = alreadyAdded || current;
    });
    return {
        byHref: byHref,
        byOldId: byOldId
    };
}
function rewriteRefs(text) {
    const merged = mergeLabels(text);
    const hrefToRefId = {};
    const labels = [];
    const rewrites = [];
    let i = 1;
    (0, _forEach.default)(findRefs(text), (ref)=>{
        const oldLabel = merged.byOldId[ref.id];
        if (!oldLabel) {
            return;
        }
        const href = oldLabel.href;
        let newRefId = hrefToRefId[href];
        if (!newRefId) {
            hrefToRefId[href] = newRefId = i;
            i += 1;
            labels.push((0, _extend.default)({
                newId: newRefId
            }, oldLabel));
        }
        rewrites.push((0, _extend.default)({
            newId: newRefId
        }, ref));
    });
    (0, _forEach.default)(findLabels(text), (label)=>{
        text = text.replace(label.match, '');
    });
    text = text.replace(/[\r\n\s]*$/, '');
    text += '\n\n';
    (0, _forEach.default)(rewrites, (ref)=>{
        text = text.replace(ref.match, buildRef(ref, ref.newId));
    });
    (0, _forEach.default)(labels, (label)=>{
        text += '\n' + buildLabel(label, label.newId);
    });
    return text;
}
function makeFinder(type) {
    return (text)=>findAll(text, type).map(PROCESSORS[type]);
}
function findMaxLabelId(textOrLabels) {
    if (textOrLabels != null && typeof textOrLabels.valueOf() === 'string') {
        textOrLabels = findLabels(textOrLabels);
    }
    const ids = textOrLabels.map((x)=>x.id).map((x)=>parseInt(x, 10)).filter((x)=>(0, _isFinite.default)(x) && x > 0);
    return ids.length > 0 ? (0, _max.default)(ids) || 0 : 0;
}
function findAll(text, type) {
    const flags = 'g' + (type === 'label' ? 'm' : '');
    const matches = [];
    const re = new RegExp(REGEXS[type].source, flags);
    let found = re.exec(text);
    while(found){
        matches.push(found);
        re.lastIndex = found.index + found[0].length;
        found = re.exec(text);
    }
    return matches;
}
function hasTitle(link) {
    return (0, _isObject.default)(link) && link.title !== null && typeof link.title.valueOf() === 'string' && link.title.length > 0;
}
function buildLabel(link, id) {
    let markup = '[' + id + ']: ' + link.href;
    if (hasTitle(link)) {
        markup += ' "' + link.title + '"';
    }
    return markup;
}
function buildRef(link, id) {
    return '[' + link.text + '][' + id + ']';
}
