"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
const _linkOrganizer = /*#__PURE__*/ _interop_require_wildcard(require("./linkOrganizer"));
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
describe('Link organizer', ()=>{
    describe('Inline link finder', ()=>{
        it('Finds all inline links in text', ()=>{
            const subject = 'test [link](http://url.com) test [link2](http://url2.com) test [link3](http://url.com)';
            const found = _linkOrganizer.findInline(subject);
            expect(found).toHaveLength(3);
            expect(found[0].match).toBe('[link](http://url.com)');
            expect(found[0].text).toBe('link');
            expect(found[0].href).toBe('http://url.com');
            expect(found[0].title).toBe('');
        });
        it('Finds and standardizes title', ()=>{
            const subject = 'test [x](http://url.com   "title!") [y](http://xyz.com title 2   )';
            const found = _linkOrganizer.findInline(subject);
            expect(found).toHaveLength(2);
            expect(found[0].title).toBe('title!');
            expect(found[1].title).toBe('title 2');
        });
    });
    describe('Reference finder', ()=>{
        it('Finds all references in text', ()=>{
            const subject = 'test [x][1] test [y][2] [with space separator] [3]';
            const found = _linkOrganizer.findRefs(subject);
            expect(found).toHaveLength(3);
            expect(found[0].match).toBe('[x][1]');
            expect(found[2].match).toBe('[with space separator] [3]');
            expect(found[1].text).toBe('y');
            expect(found[1].id).toBe('2');
        });
    });
    describe('Label finder', ()=>{
        const subject = [
            '[1]:  http://test.com',
            '[2]: http://url.com',
            '[string]: http://url.com',
            '[4]: http://test.com  "Hello world"'
        ].join('\n');
        it('Finds all labels', ()=>{
            const found = _linkOrganizer.findLabels(subject);
            expect(found).toHaveLength(4);
            expect(found[0].id).toBe('1');
            expect(found[2].id).toBe('string');
            expect(found[0].href).toBe('http://test.com');
            expect(found[3].href).toBe('http://test.com');
            expect(found[1].title).toBe('');
            expect(found[3].title).toBe('Hello world');
        });
        it('Finds max label id', ()=>{
            expect(_linkOrganizer.findMaxLabelId(subject)).toBe(4);
        });
    });
});
