import * as React from 'react';
import { Paragraph, Stack, TextLink } from '@contentful/f36-components';
import tokens from '@contentful/f36-tokens';
import { css } from 'emotion';
const SANITIZE_LINK = 'https://en.wikipedia.org/wiki/HTML_sanitization';
const styles = {
    root: css({
        display: 'flex',
        justifyContent: 'space-between',
        background: tokens.gray100,
        border: `1px solid ${tokens.gray400}`,
        borderBottomLeftRadius: tokens.borderRadiusSmall,
        borderBottomRightRadius: tokens.borderRadiusSmall,
        padding: `${tokens.spacingXs} ${tokens.spacingS}`
    }),
    help: css({
        color: tokens.gray700,
        fontSize: tokens.fontSizeS,
        '& button, & a': {
            fontSize: tokens.fontSizeS,
            lineHeight: 'inherit'
        }
    })
};
export function MarkdownCounter(props) {
    return /*#__PURE__*/ React.createElement(Paragraph, {
        marginBottom: "none",
        className: styles.help
    }, props.words, " ", props.words !== 1 ? 'words' : 'word', ", ", props.characters, ' ', props.characters !== 1 ? 'characters' : 'character');
}
function SanitizeMessage() {
    return /*#__PURE__*/ React.createElement("span", null, "The preview of the content in this field will be sanitized.", ' ', /*#__PURE__*/ React.createElement(TextLink, {
        as: "a",
        target: "_blank",
        rel: "noopener noreferrer",
        href: SANITIZE_LINK
    }, "Learn more."));
}
function CheatSheetMessage({ onClick }) {
    return /*#__PURE__*/ React.createElement("span", null, "Format your text like a pro with the", ' ', /*#__PURE__*/ React.createElement(TextLink, {
        as: "button",
        testId: "open-markdown-cheatsheet-button",
        onClick: onClick
    }, "markdown cheatsheet"), ".");
}
export function MarkdownHelp(props) {
    let content;
    switch(props.mode){
        case 'preview':
            content = /*#__PURE__*/ React.createElement(SanitizeMessage, null);
            break;
        case 'editor':
            content = /*#__PURE__*/ React.createElement(CheatSheetMessage, {
                onClick: props.onClick
            });
            break;
        case 'zen':
            content = /*#__PURE__*/ React.createElement(Stack, {
                flexDirection: "column",
                spacing: "spacing2Xs",
                alignItems: "flex-start"
            }, /*#__PURE__*/ React.createElement(CheatSheetMessage, {
                onClick: props.onClick
            }), /*#__PURE__*/ React.createElement(SanitizeMessage, null));
            break;
        default:
            content = null;
            throw new Error(`Invalid HelpMode provided in MarkdownHelp: ${props.mode}`);
    }
    return /*#__PURE__*/ React.createElement(Paragraph, {
        marginBottom: "none",
        className: styles.help
    }, content);
}
export function MarkdownBottomBar(props) {
    return /*#__PURE__*/ React.createElement("div", {
        className: styles.root
    }, props.children);
}
