import * as React from 'react';
import { Flex, IconButton, Tooltip } from '@contentful/f36-components';
import { CodeIcon, FormatBoldIcon, FormatItalicIcon, HeadingIcon, HorizontalRuleIcon, LinkIcon, ListBulletedIcon, ListNumberedIcon, MoreHorizontalIcon, QuoteIcon } from '@contentful/f36-icons';
import tokens from '@contentful/f36-tokens';
import { css, cx } from 'emotion';
import { HeadingSelector } from './HeadingSelector';
import * as Icons from './icons';
import { InsertLinkSelector } from './InsertLinkSelector';
const styles = {
    root: css({
        position: 'relative',
        zIndex: Number(tokens.zIndexWorkbenchHeader),
        border: `1px solid ${tokens.gray400}`,
        backgroundColor: tokens.gray100,
        padding: tokens.spacingXs,
        borderTopLeftRadius: tokens.borderRadiusSmall,
        overflow: 'hidden'
    }),
    button: css({
        height: '30px',
        width: '36px',
        marginLeft: tokens.spacing2Xs,
        marginRight: tokens.spacing2Xs
    }),
    icon: css({
        fill: tokens.gray700,
        verticalAlign: 'middle'
    }),
    zenButton: css({
        marginLeft: tokens.spacingXs
    }),
    zenButtonPressed: css({
        backgroundColor: tokens.gray400
    }),
    tooltip: css({
        zIndex: Number(tokens.zIndexTooltip)
    })
};
const ToolbarButton = /*#__PURE__*/ React.forwardRef((props, ref)=>{
    const { tooltip, onClick, children, className, variant = 'transparent', tooltipPlace = 'top', isDisabled = false, ...otherProps } = props;
    return /*#__PURE__*/ React.createElement(Tooltip, {
        className: styles.tooltip,
        usePortal: true,
        placement: tooltipPlace,
        content: tooltip
    }, /*#__PURE__*/ React.createElement(IconButton, {
        ...otherProps,
        ref: ref,
        className: cx(styles.button, className),
        isDisabled: isDisabled,
        onClick: onClick,
        variant: variant,
        size: "small",
        icon: children,
        "aria-label": tooltip
    }));
});
ToolbarButton.displayName = 'ToolbarButton';
function MainButtons(props) {
    const tooltipPlace = props.mode === 'zen' ? 'bottom' : 'top';
    return /*#__PURE__*/ React.createElement(React.Fragment, null, /*#__PURE__*/ React.createElement(HeadingSelector, {
        onSelect: (heading)=>{
            if (heading && props.actions.headings[heading]) {
                props.actions.headings[heading]();
            }
        }
    }, /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-heading",
        tooltip: "Headings",
        tooltipPlace: tooltipPlace
    }, /*#__PURE__*/ React.createElement(HeadingIcon, {
        "aria-label": "Headings",
        className: styles.icon
    }))), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-bold",
        tooltip: "Bold",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.bold
    }, /*#__PURE__*/ React.createElement(FormatBoldIcon, {
        "aria-label": "Bold",
        className: styles.icon
    })), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-italic",
        tooltip: "Italic",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.italic
    }, /*#__PURE__*/ React.createElement(FormatItalicIcon, {
        "aria-label": "Italic",
        className: styles.icon
    })), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-quote",
        tooltip: "Quote",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.quote
    }, /*#__PURE__*/ React.createElement(QuoteIcon, {
        "aria-label": "Quote",
        className: styles.icon
    })), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-ul",
        tooltip: "Unordered list",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.ul
    }, /*#__PURE__*/ React.createElement(ListBulletedIcon, {
        "aria-label": "Unordered list",
        className: styles.icon
    })), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-ol",
        tooltip: "Ordered list",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.ol
    }, /*#__PURE__*/ React.createElement(ListNumberedIcon, {
        "aria-label": "Ordered list",
        className: styles.icon
    })), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-link",
        tooltip: "Link",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.insertLink
    }, /*#__PURE__*/ React.createElement(LinkIcon, {
        "aria-label": "Link",
        className: styles.icon
    })));
}
function AdditionalButtons(props) {
    const tooltipPlace = props.mode === 'zen' ? 'bottom' : 'top';
    return /*#__PURE__*/ React.createElement(React.Fragment, null, /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-strike",
        tooltip: "Strike out",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.strike
    }, /*#__PURE__*/ React.createElement(Icons.Strikethrough, {
        label: "Strike out",
        className: styles.icon
    })), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-code",
        tooltip: "Code block",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.code
    }, /*#__PURE__*/ React.createElement(CodeIcon, {
        "aria-label": "Code block",
        className: styles.icon
    })), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-hr",
        tooltip: "Horizontal rule",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.hr
    }, /*#__PURE__*/ React.createElement(HorizontalRuleIcon, {
        "aria-label": "Horizontal rule",
        className: styles.icon
    })), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-indent",
        tooltip: "Increase indentation",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.indent
    }, /*#__PURE__*/ React.createElement(Icons.Indent, {
        label: "Increase indentation",
        className: styles.icon
    })), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-dedent",
        tooltip: "Decrease indentation",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.simple.dedent
    }, /*#__PURE__*/ React.createElement(Icons.Dedent, {
        label: "Decrease indentation",
        className: styles.icon
    })), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-embed",
        tooltip: "Embed external content",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.embedExternalContent
    }, /*#__PURE__*/ React.createElement(Icons.Cubes, {
        label: "Embed external content",
        className: styles.icon
    })), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-table",
        tooltip: "Insert table",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.insertTable
    }, /*#__PURE__*/ React.createElement(Icons.Table, {
        label: "Insert table",
        className: styles.icon
    })), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-special",
        tooltip: "Insert special character",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.insertSpecialCharacter
    }, /*#__PURE__*/ React.createElement(Icons.SpecialChar, {
        label: "Insert special character",
        className: styles.icon
    })), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-organizeLinks",
        tooltip: "Organize links",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.organizeLinks
    }, /*#__PURE__*/ React.createElement(Icons.OrgLinks, {
        label: "Organize links",
        className: styles.icon
    })), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-undo",
        tooltip: "Undo",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.history.undo
    }, /*#__PURE__*/ React.createElement(Icons.Undo, {
        label: "Undo",
        className: styles.icon
    })), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-redo",
        tooltip: "Redo",
        tooltipPlace: tooltipPlace,
        onClick: props.actions.history.redo
    }, /*#__PURE__*/ React.createElement(Icons.Redo, {
        label: "Redo",
        className: styles.icon
    })));
}
export function DefaultMarkdownToolbar(props) {
    const [showAdditional, setShowAdditional] = React.useState(false);
    return /*#__PURE__*/ React.createElement("div", {
        className: styles.root
    }, /*#__PURE__*/ React.createElement(Flex, {
        justifyContent: "space-between",
        flexWrap: "wrap"
    }, /*#__PURE__*/ React.createElement(Flex, {
        flexWrap: "wrap"
    }, /*#__PURE__*/ React.createElement(MainButtons, props), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-toggle-additional",
        tooltip: showAdditional ? 'Hide additional actions' : 'More actions',
        onClick: ()=>{
            setShowAdditional(!showAdditional);
        }
    }, /*#__PURE__*/ React.createElement(MoreHorizontalIcon, {
        className: styles.icon
    }))), /*#__PURE__*/ React.createElement(Flex, null, /*#__PURE__*/ React.createElement(InsertLinkSelector, {
        disabled: props.disabled,
        onSelectExisting: props.actions.linkExistingMedia,
        onAddNew: props.actions.addNewMedia,
        canAddNew: props.canUploadAssets
    }), /*#__PURE__*/ React.createElement(ToolbarButton, {
        isDisabled: props.disabled,
        testId: "markdown-action-button-zen",
        variant: "secondary",
        onClick: props.actions.openZenMode,
        className: styles.zenButton,
        tooltip: "Expand"
    }, /*#__PURE__*/ React.createElement(Icons.Zen, {
        label: "Expand",
        className: styles.icon
    })))), showAdditional && /*#__PURE__*/ React.createElement(Flex, {
        justifyContent: "space-between",
        marginTop: "spacingXs"
    }, /*#__PURE__*/ React.createElement(Flex, null, /*#__PURE__*/ React.createElement(AdditionalButtons, props))));
}
export function ZenMarkdownToolbar(props) {
    return /*#__PURE__*/ React.createElement("div", {
        className: styles.root
    }, /*#__PURE__*/ React.createElement(Flex, {
        justifyContent: "space-between",
        alignItems: "flex-start"
    }, /*#__PURE__*/ React.createElement(Flex, {
        flexWrap: "wrap"
    }, /*#__PURE__*/ React.createElement(MainButtons, props), /*#__PURE__*/ React.createElement(AdditionalButtons, props)), /*#__PURE__*/ React.createElement(Flex, null, /*#__PURE__*/ React.createElement(InsertLinkSelector, {
        disabled: props.disabled,
        onSelectExisting: props.actions.linkExistingMedia,
        onAddNew: props.actions.addNewMedia,
        canAddNew: props.canUploadAssets
    }), /*#__PURE__*/ React.createElement(IconButton, {
        testId: "markdown-action-button-zen-close",
        variant: "secondary",
        size: "small",
        className: cx(styles.zenButton, styles.zenButtonPressed),
        onClick: ()=>{
            props.actions.closeZenMode();
        },
        icon: /*#__PURE__*/ React.createElement(Icons.Zen, {
            label: "Collapse",
            className: styles.icon
        }),
        "aria-label": "Collapse"
    }))));
}
export const MarkdownToolbar = /*#__PURE__*/ React.memo((props)=>{
    if (props.mode === 'zen') {
        return /*#__PURE__*/ React.createElement(ZenMarkdownToolbar, props);
    }
    return /*#__PURE__*/ React.createElement(DefaultMarkdownToolbar, props);
});
MarkdownToolbar.displayName = 'MarkdownToolbar';
