import * as React from 'react';
import { Heading, ModalContent, TextLink } from '@contentful/f36-components';
import tokens from '@contentful/f36-tokens';
import { css, cx } from 'emotion';
import { MarkdownDialogType } from '../types';
const styles = {
    flexColumnContainer: css({
        display: 'flex',
        flexWrap: 'nowrap'
    }),
    flexColumn: css({
        flexGrow: 1
    }),
    verticalDivider: css({
        borderRight: `1px solid ${tokens.gray500}`,
        paddingRight: tokens.spacing3Xl,
        marginRight: tokens.spacing2Xl
    }),
    preview: css({
        display: 'inline-block',
        paddingRight: tokens.spacingL,
        width: '50%'
    }),
    unOrderedListPreview: css({
        listStyleType: 'disc',
        marginLeft: tokens.spacingS
    }),
    orderedListPreview: css({
        listStyleType: 'decimal',
        marginLeft: tokens.spacingS
    }),
    markup: css({
        display: 'inline-block',
        color: tokens.gray600,
        paddingLeft: tokens.spacingL,
        width: '50%'
    }),
    h1: css({
        fontSize: tokens.fontSize2Xl
    }),
    h2: css({
        fontSize: tokens.fontSizeXl
    }),
    h3: css({
        fontSize: tokens.fontSizeL
    }),
    helpItem: css({
        marginBottom: tokens.spacingS,
        display: 'flex',
        alignItems: 'flex-end',
        height: tokens.spacingXl
    }),
    helpLink: css({
        margin: 'auto'
    }),
    flexRowContainer: css({
        display: 'flex',
        width: '100%',
        justifyContent: 'center',
        marginTop: tokens.spacingXl
    })
};
export const CheatsheetModalDialog = ()=>{
    return /*#__PURE__*/ React.createElement(ModalContent, {
        testId: "markdown-cheatsheet-dialog-content"
    }, /*#__PURE__*/ React.createElement("div", {
        className: styles.flexColumnContainer
    }, /*#__PURE__*/ React.createElement("div", {
        className: cx(styles.flexColumn, styles.verticalDivider)
    }, /*#__PURE__*/ React.createElement("div", {
        className: styles.helpItem
    }, /*#__PURE__*/ React.createElement(Heading, {
        marginBottom: "none",
        as: "h1",
        className: cx(styles.preview, styles.h1)
    }, "H1"), /*#__PURE__*/ React.createElement("div", {
        className: styles.markup
    }, "# heading")), /*#__PURE__*/ React.createElement("div", {
        className: styles.helpItem
    }, /*#__PURE__*/ React.createElement(Heading, {
        marginBottom: "none",
        as: "h2",
        className: cx(styles.preview, styles.h2)
    }, "H2"), /*#__PURE__*/ React.createElement("div", {
        className: styles.markup
    }, "## heading")), /*#__PURE__*/ React.createElement("div", {
        className: styles.helpItem
    }, /*#__PURE__*/ React.createElement(Heading, {
        marginBottom: "none",
        as: "h3",
        className: cx(styles.preview, styles.h3)
    }, "H3"), /*#__PURE__*/ React.createElement("div", {
        className: styles.markup
    }, "### heading")), /*#__PURE__*/ React.createElement("div", {
        className: styles.helpItem
    }, /*#__PURE__*/ React.createElement("strong", {
        className: styles.preview
    }, "bold"), /*#__PURE__*/ React.createElement("div", {
        className: styles.markup
    }, "__text__")), /*#__PURE__*/ React.createElement("div", {
        className: styles.helpItem
    }, /*#__PURE__*/ React.createElement("em", {
        className: styles.preview
    }, "italic"), /*#__PURE__*/ React.createElement("div", {
        className: styles.markup
    }, "*text*")), /*#__PURE__*/ React.createElement("div", {
        className: styles.helpItem
    }, /*#__PURE__*/ React.createElement("div", {
        className: styles.preview
    }, "strikethrough"), /*#__PURE__*/ React.createElement("div", {
        className: styles.markup
    }, "~~text~~")), /*#__PURE__*/ React.createElement("div", {
        className: styles.helpItem
    }, /*#__PURE__*/ React.createElement(TextLink, {
        as: "button",
        className: styles.preview
    }, "Link"), /*#__PURE__*/ React.createElement("div", {
        className: styles.markup
    }, "[text](url)"))), /*#__PURE__*/ React.createElement("div", {
        className: styles.flexColumn
    }, /*#__PURE__*/ React.createElement("div", {
        className: styles.helpItem
    }, /*#__PURE__*/ React.createElement("div", {
        className: styles.preview
    }, "Image"), /*#__PURE__*/ React.createElement("div", {
        className: styles.markup
    }, "![alt-text](url)")), /*#__PURE__*/ React.createElement("div", {
        className: styles.helpItem
    }, /*#__PURE__*/ React.createElement("div", {
        className: styles.preview
    }, "Unordered list"), /*#__PURE__*/ React.createElement("div", {
        className: styles.markup
    }, "* list item")), /*#__PURE__*/ React.createElement("div", {
        className: styles.helpItem
    }, /*#__PURE__*/ React.createElement("div", {
        className: styles.preview
    }, /*#__PURE__*/ React.createElement("div", null, "Ordered list")), /*#__PURE__*/ React.createElement("div", {
        className: styles.markup
    }, "1. list item")), /*#__PURE__*/ React.createElement("div", {
        className: styles.helpItem
    }, /*#__PURE__*/ React.createElement("div", {
        className: styles.preview
    }, /*#__PURE__*/ React.createElement("div", null, "Blockquote")), /*#__PURE__*/ React.createElement("div", {
        className: styles.markup
    }, "> quote")), /*#__PURE__*/ React.createElement("div", {
        className: styles.helpItem
    }, /*#__PURE__*/ React.createElement("div", {
        className: styles.preview
    }, "code span"), /*#__PURE__*/ React.createElement("div", {
        className: styles.markup
    }, "`code here`")), /*#__PURE__*/ React.createElement("div", {
        className: styles.helpItem
    }, /*#__PURE__*/ React.createElement("div", {
        className: styles.preview
    }, "code block"), /*#__PURE__*/ React.createElement("div", {
        className: styles.markup
    }, "```code here```")))), /*#__PURE__*/ React.createElement("div", {
        className: styles.flexRowContainer
    }, /*#__PURE__*/ React.createElement(TextLink, {
        className: styles.helpLink,
        href: "https://help.github.com/en/github/writing-on-github/basic-writing-and-formatting-syntax",
        target: "_blank",
        rel: "noopener noreferrer"
    }, "View the full GitHub-flavored Markdown syntax help (opens in a new window)")));
};
export const openCheatsheetModal = (dialogs)=>{
    return dialogs.openCurrent({
        title: 'Markdown formatting help',
        width: 'large',
        minHeight: '415px',
        shouldCloseOnEscapePress: true,
        shouldCloseOnOverlayClick: true,
        parameters: {
            type: MarkdownDialogType.cheatsheet
        }
    });
};
