import React, { useState, useRef, useEffect } from 'react';
import { ModalContent, ModalControls, Text, TextLink, Button, Checkbox, Radio, Form, FormControl, TextInput } from '@contentful/f36-components';
import tokens from '@contentful/f36-tokens';
import { css } from 'emotion';
import { MarkdownDialogType } from '../types';
import { isValidUrl } from '../utils/isValidUrl';
const styles = {
    widthFiledGroup: css({
        display: 'flex',
        flexWrap: 'nowrap',
        alignItems: 'flex-start'
    }),
    radioButtonGroup: css({
        display: 'inline-flex',
        alignItems: 'flex-start',
        paddingTop: tokens.spacingXl
    }),
    radioButton: css({
        marginLeft: tokens.spacingM
    })
};
const makeEmbedlyLink = ({ url, width, selectedUnit, attachSocial })=>{
    const s = {
        percent: '%',
        px: 'px'
    };
    return [
        '<a href="' + url + '" class="embedly-card" ',
        'data-card-width="' + width + s[selectedUnit] + '" ',
        'data-card-controls="' + (attachSocial ? '1' : '0') + '"',
        '>Embedded content: ' + url + '</a>'
    ].join('');
};
const isWidthValid = (width, unit)=>unit === 'percent' ? width <= 100 : true;
export const EmbedExternalContentModal = ({ onClose })=>{
    const mainInputRef = useRef(null);
    const [url, setUrl] = useState('https://');
    const [selectedUnit, setUnit] = useState('percent');
    const [urlIsValid, setUrlValidity] = useState(true);
    const [width, setWidth] = useState('100');
    const [attachSocial, setAttachSocial] = useState(false);
    useEffect(()=>{
        if (mainInputRef.current?.focus) {
            mainInputRef.current.focus();
        }
    }, [
        mainInputRef
    ]);
    return /*#__PURE__*/ React.createElement(React.Fragment, null, /*#__PURE__*/ React.createElement(ModalContent, {
        testId: "embed-external-dialog"
    }, /*#__PURE__*/ React.createElement(Form, null, /*#__PURE__*/ React.createElement(FormControl, {
        id: "external-link-url-field",
        isRequired: true,
        isInvalid: !urlIsValid
    }, /*#__PURE__*/ React.createElement(FormControl.Label, null, "Content URL"), /*#__PURE__*/ React.createElement(TextInput, {
        name: "external-link-url",
        value: url,
        onChange: (e)=>{
            const value = e.target.value;
            setUrl(value);
            setUrlValidity(isValidUrl(value));
        },
        testId: "external-link-url-field",
        placeholder: "https://example.com",
        ref: mainInputRef
    }), /*#__PURE__*/ React.createElement(FormControl.HelpText, null, "Include protocol (e.g. https://)"), !urlIsValid && /*#__PURE__*/ React.createElement(FormControl.ValidationMessage, null, "URL is invalid")), /*#__PURE__*/ React.createElement(TextLink, {
        href: "http://embed.ly/providers",
        target: "_blank",
        rel: "noopener noreferrer"
    }, "Supported sources"), /*#__PURE__*/ React.createElement("div", {
        className: styles.widthFiledGroup
    }, /*#__PURE__*/ React.createElement(FormControl, {
        id: "embedded-content-width",
        isRequired: true,
        isInvalid: !isWidthValid(Number(width), selectedUnit)
    }, /*#__PURE__*/ React.createElement(FormControl.Label, null, "Width"), /*#__PURE__*/ React.createElement(TextInput, {
        value: width,
        name: "embedded-content-width",
        testId: "embedded-content-width",
        type: "number",
        width: "small",
        onChange: (e)=>setWidth(e.target.value)
    }), !isWidthValid(Number(width), selectedUnit) && /*#__PURE__*/ React.createElement(FormControl.ValidationMessage, null, "Should be equal or less then 100")), /*#__PURE__*/ React.createElement("div", {
        className: styles.radioButtonGroup
    }, /*#__PURE__*/ React.createElement(Radio, {
        id: "unit-option-percent",
        value: "percent",
        isChecked: selectedUnit === 'percent',
        onChange: ()=>setUnit('percent'),
        className: styles.radioButton
    }, "percent"), /*#__PURE__*/ React.createElement(Radio, {
        id: "unit-option-pixels",
        value: "pixels",
        isChecked: selectedUnit === 'px',
        onChange: ()=>setUnit('px'),
        className: styles.radioButton
    }, "pixels"))), /*#__PURE__*/ React.createElement(Checkbox, {
        id: "attach-social-checkbox",
        name: "attach-social-checkbox",
        value: "Yes",
        isChecked: attachSocial,
        onChange: ()=>setAttachSocial(!attachSocial),
        testId: "attach-social-checkbox"
    }, "Attach social sharing links to this element"), /*#__PURE__*/ React.createElement(Text, {
        as: "p",
        fontColor: "gray500",
        marginTop: "spacingXs"
    }, "To enable this embedded content in your application make sure to add the ", /*#__PURE__*/ React.createElement(TextLink, {
        href: "http://embed.ly/docs/products/cards",
        target: "_blank",
        rel: "noopener noreferrer"
    }, "Embedly's platform.js"), " on your development environment"))), /*#__PURE__*/ React.createElement(ModalControls, null, /*#__PURE__*/ React.createElement(Button, {
        testId: "emded-external-cancel",
        onClick: ()=>onClose(false),
        variant: "secondary",
        size: "small"
    }, "Cancel"), /*#__PURE__*/ React.createElement(Button, {
        testId: "embed-external-confirm",
        onClick: ()=>onClose(makeEmbedlyLink({
                url,
                width: Number(width),
                selectedUnit,
                attachSocial
            })),
        variant: "positive",
        size: "small"
    }, "Insert")));
};
export const openEmbedExternalContentDialog = (dialogs)=>{
    return dialogs.openCurrent({
        title: 'Embed external content',
        width: 'large',
        minHeight: '435px',
        shouldCloseOnEscapePress: true,
        shouldCloseOnOverlayClick: true,
        parameters: {
            type: MarkdownDialogType.embedExternalContent
        }
    });
};
