import React, { useState, useRef, useEffect } from 'react';
import { ModalContent, ModalControls, Button, Form, FormControl, TextInput } from '@contentful/f36-components';
import { MarkdownDialogType } from '../types';
import { isValidUrl } from '../utils/isValidUrl';
export const InsertLinkModal = ({ selectedText, onClose })=>{
    const mainInputRef = useRef(null);
    const [text, setText] = useState(selectedText || '');
    const [url, setUrl] = useState('');
    const [touched, setTouched] = useState(false);
    const [title, setTitle] = useState('');
    const onInsert = (values)=>onClose(values);
    const urlIsValid = isValidUrl(url);
    useEffect(()=>{
        if (mainInputRef?.current?.focus) {
            mainInputRef.current.focus();
        }
    }, [
        mainInputRef
    ]);
    return /*#__PURE__*/ React.createElement(React.Fragment, null, /*#__PURE__*/ React.createElement(ModalContent, {
        testId: "insert-link-modal"
    }, /*#__PURE__*/ React.createElement(Form, {
        onSubmit: ()=>onInsert({
                url,
                text,
                title
            })
    }, /*#__PURE__*/ React.createElement(FormControl, {
        id: "link-text-field",
        isDisabled: Boolean(selectedText)
    }, /*#__PURE__*/ React.createElement(FormControl.Label, null, "Link text"), /*#__PURE__*/ React.createElement(TextInput, {
        name: "link-text",
        value: text,
        onChange: (e)=>{
            setText(e.target.value);
        },
        testId: "link-text-field"
    })), /*#__PURE__*/ React.createElement(FormControl, {
        id: "target-url-field",
        isInvalid: touched && !urlIsValid
    }, /*#__PURE__*/ React.createElement(FormControl.Label, null, "Target URL"), /*#__PURE__*/ React.createElement(TextInput, {
        name: "target-url",
        value: url,
        onChange: (e)=>{
            setUrl(e.target.value);
            setTouched(true);
        },
        placeholder: "https://",
        maxLength: 2100,
        testId: "target-url-field",
        ref: mainInputRef
    }), /*#__PURE__*/ React.createElement(FormControl.HelpText, null, "Include protocol (e.g. https://)"), touched && !urlIsValid && /*#__PURE__*/ React.createElement(FormControl.ValidationMessage, null, "Invalid URL")), /*#__PURE__*/ React.createElement(FormControl, {
        id: "link-title-field"
    }, /*#__PURE__*/ React.createElement(FormControl.Label, null, "Link title"), /*#__PURE__*/ React.createElement(TextInput, {
        name: "link-title",
        value: title,
        onChange: (e)=>{
            setTitle(e.target.value);
        },
        testId: "link-title-field"
    }), /*#__PURE__*/ React.createElement(FormControl.HelpText, null, "Extra link information, usually shown as a tooltip on mouse hover")))), /*#__PURE__*/ React.createElement(ModalControls, null, /*#__PURE__*/ React.createElement(Button, {
        testId: "insert-link-cancel",
        onClick: ()=>onClose(false),
        variant: "secondary",
        size: "small"
    }, "Cancel"), /*#__PURE__*/ React.createElement(Button, {
        testId: "insert-link-confirm",
        onClick: ()=>{
            onInsert({
                url,
                text,
                title
            });
        },
        isDisabled: !urlIsValid,
        variant: "positive",
        size: "small"
    }, "Insert")));
};
export const openInsertLinkDialog = (dialogs, params)=>{
    return dialogs.openCurrent({
        title: 'Insert link',
        width: 'large',
        minHeight: '410px',
        shouldCloseOnEscapePress: true,
        shouldCloseOnOverlayClick: true,
        parameters: {
            type: MarkdownDialogType.insertLink,
            ...params
        }
    });
};
