import React, { useState, useRef, useEffect } from 'react';
import { ModalContent, ModalControls, Button, Form, FormControl, TextInput } from '@contentful/f36-components';
import inRange from 'lodash/inRange';
import { MarkdownDialogType } from '../types';
export const InsertTableModal = ({ onClose })=>{
    const mainInputRef = useRef(null);
    const [rows, setRows] = useState(2);
    const [cols, setColumns] = useState(1);
    const rowsAreValid = inRange(rows, 2, 100);
    const colsAreValid = inRange(cols, 1, 100);
    useEffect(()=>{
        if (mainInputRef.current?.focus) {
            mainInputRef.current.focus();
        }
    }, [
        mainInputRef
    ]);
    return /*#__PURE__*/ React.createElement(React.Fragment, null, /*#__PURE__*/ React.createElement(ModalContent, {
        testId: "insert-table-modal"
    }, /*#__PURE__*/ React.createElement(Form, null, /*#__PURE__*/ React.createElement(FormControl, {
        id: "insert-table-rows-number-field",
        isRequired: true,
        isInvalid: !rowsAreValid
    }, /*#__PURE__*/ React.createElement(FormControl.Label, null, "Number of rows"), /*#__PURE__*/ React.createElement(TextInput, {
        name: "rows",
        value: rows.toString(),
        onChange: (e)=>setRows(Number(e.target.value)),
        testId: "insert-table-rows-number-field",
        min: 2,
        max: 100,
        pattern: "[1-9][0-9]*",
        type: "number",
        width: "small",
        autoComplete: "off",
        ref: mainInputRef
    }), !rowsAreValid && /*#__PURE__*/ React.createElement(FormControl.ValidationMessage, null, "Should be between 2 and 100")), /*#__PURE__*/ React.createElement(FormControl, {
        id: "insert-table-columns-number-field",
        isRequired: true,
        isInvalid: !colsAreValid
    }, /*#__PURE__*/ React.createElement(FormControl.Label, null, "Number of columns"), /*#__PURE__*/ React.createElement(TextInput, {
        name: "columns",
        value: cols.toString(),
        onChange: (e)=>setColumns(Number(e.target.value)),
        testId: "insert-table-columns-number-field",
        min: 1,
        max: 100,
        pattern: "[1-9][0-9]*",
        type: "number",
        width: "small",
        autoComplete: "off"
    }), !colsAreValid && /*#__PURE__*/ React.createElement(FormControl.ValidationMessage, null, "Should be between 1 and 100")))), /*#__PURE__*/ React.createElement(ModalControls, null, /*#__PURE__*/ React.createElement(Button, {
        testId: "insert-table-cancel",
        onClick: ()=>onClose(false),
        variant: "secondary",
        size: "small"
    }, "Cancel"), /*#__PURE__*/ React.createElement(Button, {
        testId: "insert-table-confirm",
        onClick: ()=>onClose({
                rows,
                cols
            }),
        variant: "positive",
        size: "small",
        isDisabled: !rowsAreValid || !colsAreValid
    }, "Insert")));
};
export const openInsertTableDialog = (dialogs)=>{
    return dialogs.openCurrent({
        title: 'Insert table',
        width: 'medium',
        minHeight: '260px',
        shouldCloseOnEscapePress: true,
        shouldCloseOnOverlayClick: true,
        parameters: {
            type: MarkdownDialogType.insertTable
        }
    });
};
