import React, { useState } from 'react';
import { ModalContent, ModalControls, Text, Flex, Button, Tooltip } from '@contentful/f36-components';
import tokens from '@contentful/f36-tokens';
import { css } from 'emotion';
import { MarkdownDialogType } from '../types';
import { specialCharacters } from '../utils/specialCharacters';
const styles = {
    buttonPanel: css({
        display: 'flex',
        flexWrap: 'wrap'
    }),
    charButton: css({
        border: `1px solid ${tokens.gray500}`,
        width: '4.1rem',
        height: '4.1rem',
        fontSize: tokens.fontSizeXl,
        marginTop: tokens.spacing2Xs,
        marginRight: tokens.spacing2Xs
    }),
    selectedCharButton: css({
        backgroundColor: tokens.gray100
    }),
    tooltip: css({
        zIndex: 1000
    }),
    button: css({
        marginTop: tokens.spacingM,
        marginRight: tokens.spacingS
    })
};
export const SpecialCharacterModalDialog = ({ onClose })=>{
    const [selectedCharacter, setSelectedCharacter] = useState(specialCharacters[0]);
    return /*#__PURE__*/ React.createElement(React.Fragment, null, /*#__PURE__*/ React.createElement(ModalContent, {
        testId: "insert-special-character-modal"
    }, /*#__PURE__*/ React.createElement(Flex, {
        flexDirection: "column",
        alignItems: "center"
    }, /*#__PURE__*/ React.createElement(Text, {
        as: "div",
        lineHeight: "lineHeight3Xl",
        fontSize: "fontSize3Xl",
        marginBottom: "spacingS"
    }, String.fromCharCode(selectedCharacter.code)), /*#__PURE__*/ React.createElement(Text, {
        as: "div",
        marginBottom: "spacingS"
    }, selectedCharacter.desc)), /*#__PURE__*/ React.createElement("div", {
        className: styles.buttonPanel
    }, specialCharacters.map((char)=>/*#__PURE__*/ React.createElement("div", {
            key: char.code
        }, /*#__PURE__*/ React.createElement(Tooltip, {
            className: styles.tooltip,
            content: char.desc
        }, /*#__PURE__*/ React.createElement(Button, {
            testId: "special-character-button",
            isActive: char.code === selectedCharacter.code,
            className: styles.charButton,
            variant: "transparent",
            onClick: ()=>setSelectedCharacter(char)
        }, String.fromCharCode(char.code))))))), /*#__PURE__*/ React.createElement(ModalControls, null, /*#__PURE__*/ React.createElement(Button, {
        testId: "insert-character-cancel",
        className: styles.button,
        onClick: ()=>onClose(false),
        variant: "secondary",
        size: "small"
    }, "Cancel"), /*#__PURE__*/ React.createElement(Button, {
        className: styles.button,
        testId: "insert-character-confirm",
        onClick: ()=>onClose(String.fromCharCode(selectedCharacter.code)),
        variant: "positive",
        size: "small"
    }, "Insert selected")));
};
export const openInsertSpecialCharacter = (dialogs)=>{
    return dialogs.openCurrent({
        title: 'Insert special character',
        width: 'large',
        minHeight: '600px',
        shouldCloseOnEscapePress: true,
        shouldCloseOnOverlayClick: true,
        parameters: {
            type: MarkdownDialogType.insertSpecialCharacter
        }
    });
};
