import * as React from 'react';
import { ModalDialogLauncher } from '@contentful/field-editor-shared';
import { MarkdownDialogType } from '../types';
import { CheatsheetModalDialog } from './CheatsheetModalDialog';
import { ConfirmInsertAssetModalDialog } from './ConfirmInsertAssetModalDialog';
import { EmbedExternalContentModal } from './EmdebExternalContentDialog';
import { InsertLinkModal } from './InsertLinkModalDialog';
import { InsertTableModal } from './InsertTableModalDialog';
import { SpecialCharacterModalDialog } from './SpecialCharacterModalDialog';
import { ZenModeModalDialog } from './ZenModeModalDialog';
export const openMarkdownDialog = (sdk, previewComponents)=>(options)=>{
        if (options.parameters?.type === MarkdownDialogType.cheatsheet) {
            return ModalDialogLauncher.openDialog(options, ()=>{
                return /*#__PURE__*/ React.createElement(CheatsheetModalDialog, null);
            });
        } else if (options.parameters?.type === MarkdownDialogType.insertLink) {
            const selectedText = options.parameters.selectedText;
            return ModalDialogLauncher.openDialog(options, ({ onClose })=>{
                return /*#__PURE__*/ React.createElement(InsertLinkModal, {
                    selectedText: selectedText,
                    onClose: onClose
                });
            });
        } else if (options.parameters?.type === MarkdownDialogType.insertSpecialCharacter) {
            return ModalDialogLauncher.openDialog(options, ({ onClose })=>{
                return /*#__PURE__*/ React.createElement(SpecialCharacterModalDialog, {
                    onClose: onClose
                });
            });
        } else if (options.parameters?.type === MarkdownDialogType.insertTable) {
            return ModalDialogLauncher.openDialog(options, ({ onClose })=>{
                return /*#__PURE__*/ React.createElement(InsertTableModal, {
                    onClose: onClose
                });
            });
        } else if (options.parameters?.type === MarkdownDialogType.embedExternalContent) {
            return ModalDialogLauncher.openDialog(options, ({ onClose })=>{
                return /*#__PURE__*/ React.createElement(EmbedExternalContentModal, {
                    onClose: onClose
                });
            });
        } else if (options.parameters?.type === MarkdownDialogType.confirmInsertAsset) {
            const locale = options.parameters.locale;
            const assets = options.parameters.assets;
            return ModalDialogLauncher.openDialog(options, ({ onClose })=>{
                return /*#__PURE__*/ React.createElement(ConfirmInsertAssetModalDialog, {
                    onClose: onClose,
                    locale: locale,
                    assets: assets
                });
            });
        } else if (options.parameters?.type === MarkdownDialogType.zenMode) {
            const initialValue = options.parameters.initialValue;
            const locale = options.parameters.locale;
            return ModalDialogLauncher.openDialog(options, ({ onClose })=>{
                return /*#__PURE__*/ React.createElement(ZenModeModalDialog, {
                    saveValueToSDK: (value)=>{
                        if (value) {
                            return sdk?.field?.setValue(value);
                        }
                        return sdk?.field?.removeValue();
                    },
                    onClose: onClose,
                    initialValue: initialValue,
                    locale: locale,
                    sdk: sdk,
                    previewComponents: previewComponents
                });
            });
        }
        return Promise.reject();
    };
