import * as React from 'react';
import { MarkdownDialogType } from '../types';
import { CheatsheetModalDialog } from './CheatsheetModalDialog';
import { ConfirmInsertAssetModalDialog } from './ConfirmInsertAssetModalDialog';
import { EmbedExternalContentModal } from './EmdebExternalContentDialog';
import { InsertLinkModal } from './InsertLinkModalDialog';
import { InsertTableModal } from './InsertTableModalDialog';
import { SpecialCharacterModalDialog } from './SpecialCharacterModalDialog';
import { ZenModeModalDialog } from './ZenModeModalDialog';
export const renderMarkdownDialog = (sdk)=>{
    const parameters = sdk.parameters.invocation;
    if (parameters.type === MarkdownDialogType.cheatsheet) {
        sdk.window.startAutoResizer();
        return /*#__PURE__*/ React.createElement(CheatsheetModalDialog, null);
    } else if (parameters.type === MarkdownDialogType.insertLink) {
        const selectedText = parameters.selectedText;
        sdk.window.startAutoResizer();
        return /*#__PURE__*/ React.createElement(InsertLinkModal, {
            selectedText: selectedText,
            onClose: sdk.close
        });
    } else if (parameters.type === MarkdownDialogType.insertSpecialCharacter) {
        sdk.window.startAutoResizer();
        return /*#__PURE__*/ React.createElement(SpecialCharacterModalDialog, {
            onClose: sdk.close
        });
    } else if (parameters.type === MarkdownDialogType.insertTable) {
        sdk.window.startAutoResizer();
        return /*#__PURE__*/ React.createElement(InsertTableModal, {
            onClose: sdk.close
        });
    } else if (parameters.type === MarkdownDialogType.embedExternalContent) {
        sdk.window.startAutoResizer();
        return /*#__PURE__*/ React.createElement(EmbedExternalContentModal, {
            onClose: sdk.close
        });
    } else if (parameters.type === MarkdownDialogType.confirmInsertAsset) {
        const locale = parameters.locale;
        const assets = parameters.assets;
        sdk.window.startAutoResizer();
        return /*#__PURE__*/ React.createElement(ConfirmInsertAssetModalDialog, {
            onClose: sdk.close,
            locale: locale,
            assets: assets
        });
    } else if (parameters.type === MarkdownDialogType.zenMode) {
        const locale = parameters.locale;
        const initialValue = parameters.initialValue;
        sdk.window.updateHeight('100%');
        return /*#__PURE__*/ React.createElement(ZenModeModalDialog, {
            onClose: sdk.close,
            saveValueToSDK: ()=>{},
            initialValue: initialValue,
            locale: locale,
            sdk: sdk
        });
    }
    return /*#__PURE__*/ React.createElement("div", null);
};
